@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -48,7 +48,7 @@ class Cache
      * @param Filesystem  $filesystem optional filesystem instance
      * @param bool        $readOnly   whether the cache is in readOnly mode
      */
-    public function __construct(IOInterface $io, $cacheDir, $allowlist = 'a-z0-9.', Filesystem $filesystem = null, $readOnly = false)
+    public function __construct(IOInterface $io, string $cacheDir, string $allowlist = 'a-z0-9.', Filesystem $filesystem = null, bool $readOnly = false)
     {
         $this->io = $io;
         $this->root = rtrim($cacheDir, '/\\') . '/';
@@ -66,7 +66,7 @@ class Cache
      *
      * @return void
      */
-    public function setReadOnly($readOnly)
+    public function setReadOnly(bool $readOnly)
     {
         $this->readOnly = (bool) $readOnly;
     }
@@ -84,7 +84,7 @@ class Cache
      *
      * @return bool
      */
-    public static function isUsable($path)
+    public static function isUsable(string $path)
     {
         return !Preg::isMatch('{(^|[\\\\/])(\$null|nul|NUL|/dev/null)([\\\\/]|$)}', $path);
     }
@@ -98,10 +98,13 @@ class Cache
             $this->enabled = true;
 
             if (
-                (!is_dir($this->root) && !Silencer::call('mkdir', $this->root, 0777, true))
-                || !is_writable($this->root)
+                !$this->readOnly
+                && (
+                    (!is_dir($this->root) && !Silencer::call('mkdir', $this->root, 0777, true))
+                    || !is_writable($this->root)
+                )
             ) {
-                $this->io->writeError('<warning>Cannot create cache directory ' . $this->root . ', or directory is not writable. Proceeding without cache</warning>');
+                $this->io->writeError('<warning>Cannot create cache directory ' . $this->root . ', or directory is not writable. Proceeding without cache. See also cache-read-only config if your filesystem is read-only.</warning>');
                 $this->enabled = false;
             }
         }
@@ -122,7 +125,7 @@ class Cache
      *
      * @return string|false
      */
-    public function read($file)
+    public function read(string $file)
     {
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
@@ -142,7 +145,7 @@ class Cache
      *
      * @return bool
      */
-    public function write($file, $contents)
+    public function write(string $file, string $contents)
     {
         if ($this->isEnabled() && !$this->readOnly) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
@@ -186,7 +189,7 @@ class Cache
      *
      * @return bool
      */
-    public function copyFrom($file, $source)
+    public function copyFrom(string $file, string $source)
     {
         if ($this->isEnabled() && !$this->readOnly) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
@@ -212,13 +215,13 @@ class Cache
      *
      * @return bool
      */
-    public function copyTo($file, $target)
+    public function copyTo(string $file, string $target)
     {
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
             if (file_exists($this->root . $file)) {
                 try {
-                    touch($this->root . $file, filemtime($this->root . $file), time());
+                    touch($this->root . $file, (int) filemtime($this->root . $file), time());
                 } catch (\ErrorException $e) {
                     // fallback in case the above failed due to incorrect ownership
                     // see https://github.com/composer/composer/issues/4070
@@ -248,11 +251,7 @@ class Cache
             return false;
         }
 
-        if (PHP_VERSION_ID > 70000) {
-            return !random_int(0, 50);
-        }
-
-        return !mt_rand(0, 50);
+        return !random_int(0, 50);
     }
 
     /**
@@ -260,9 +259,9 @@ class Cache
      *
      * @return bool
      */
-    public function remove($file)
+    public function remove(string $file)
     {
-        if ($this->isEnabled()) {
+        if ($this->isEnabled() && !$this->readOnly) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
             if (file_exists($this->root . $file)) {
                 return $this->filesystem->unlink($this->root . $file);
@@ -277,7 +276,7 @@ class Cache
      */
     public function clear()
     {
-        if ($this->isEnabled()) {
+        if ($this->isEnabled() && !$this->readOnly) {
             $this->filesystem->emptyDirectory($this->root);
 
             return true;
@@ -291,7 +290,7 @@ class Cache
      * @return int|false
      * @phpstan-return int<0, max>|false
      */
-    public function getAge($file)
+    public function getAge(string $file)
     {
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
@@ -309,9 +308,9 @@ class Cache
      *
      * @return bool
      */
-    public function gc($ttl, $maxSize)
+    public function gc(int $ttl, int $maxSize)
     {
-        if ($this->isEnabled()) {
+        if ($this->isEnabled() && !$this->readOnly) {
             $expire = new \DateTime();
             $expire->modify('-'.$ttl.' seconds');
 
@@ -344,7 +343,7 @@ class Cache
      *
      * @return string|false
      */
-    public function sha1($file)
+    public function sha1(string $file)
     {
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
@@ -361,7 +360,7 @@ class Cache
      *
      * @return string|false
      */
-    public function sha256($file)
+    public function sha256(string $file)
     {
         if ($this->isEnabled()) {
             $file = Preg::replace('{[^'.$this->allowlist.']}i', '-', $file);
