@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -33,7 +33,7 @@ class HomeCommand extends BaseCommand
      *
      * @return void
      */
-    protected function configure()
+    protected function configure(): void
     {
         $this
             ->setName('browse')
@@ -57,19 +57,16 @@ EOT
             );
     }
 
-    /**
-     * @inheritDoc
-     */
-    protected function execute(InputInterface $input, OutputInterface $output)
+    protected function execute(InputInterface $input, OutputInterface $output): int
     {
         $repos = $this->initializeRepos();
         $io = $this->getIO();
         $return = 0;
 
         $packages = $input->getArgument('packages');
-        if (!$packages) {
+        if (count($packages) === 0) {
             $io->writeError('No package specified, opening homepage for the root package');
-            $packages = array($this->getComposer()->getPackage()->getName());
+            $packages = array($this->requireComposer()->getPackage()->getName());
         }
 
         foreach ($packages as $packageName) {
@@ -104,10 +101,10 @@ EOT
      * @param bool $showOnly
      * @return bool
      */
-    private function handlePackage(CompletePackageInterface $package, $showHomepage, $showOnly)
+    private function handlePackage(CompletePackageInterface $package, bool $showHomepage, bool $showOnly): bool
     {
         $support = $package->getSupport();
-        $url = isset($support['source']) ? $support['source'] : $package->getSourceUrl();
+        $url = $support['source'] ?? $package->getSourceUrl();
         if (!$url || $showHomepage) {
             $url = $package->getHomepage();
         }
@@ -131,7 +128,7 @@ EOT
      * @param string $url
      * @return void
      */
-    private function openBrowser($url)
+    private function openBrowser(string $url): void
     {
         $url = ProcessExecutor::escape($url);
 
@@ -161,9 +158,9 @@ EOT
      *
      * @return RepositoryInterface[]
      */
-    private function initializeRepos()
+    private function initializeRepos(): array
     {
-        $composer = $this->getComposer(false);
+        $composer = $this->tryComposer();
 
         if ($composer) {
             return array_merge(
@@ -173,6 +170,6 @@ EOT
             );
         }
 
-        return RepositoryFactory::defaultRepos($this->getIO());
+        return RepositoryFactory::defaultReposWithDefaultManager($this->getIO());
     }
 }
