@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -54,7 +54,7 @@ class RuleWatchNode
      * @param Decisions $decisions The decisions made so far by the solver
      * @return void
      */
-    public function watch2OnHighest(Decisions $decisions)
+    public function watch2OnHighest(Decisions $decisions): void
     {
         $literals = $this->rule->getLiterals();
 
@@ -80,7 +80,7 @@ class RuleWatchNode
      *
      * @return Rule
      */
-    public function getRule()
+    public function getRule(): Rule
     {
         return $this->rule;
     }
@@ -91,7 +91,7 @@ class RuleWatchNode
      * @param  int $literal The watched literal that should not be returned
      * @return int A literal
      */
-    public function getOtherWatch($literal)
+    public function getOtherWatch(int $literal): int
     {
         if ($this->watch1 == $literal) {
             return $this->watch2;
@@ -107,7 +107,7 @@ class RuleWatchNode
      * @param int $to   The literal to be watched now
      * @return void
      */
-    public function moveWatch($from, $to)
+    public function moveWatch(int $from, int $to): void
     {
         if ($this->watch1 == $from) {
             $this->watch1 = $to;
