@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -50,7 +50,7 @@ class Transaction
      * @param PackageInterface[] $presentPackages
      * @param PackageInterface[] $resultPackages
      */
-    public function __construct($presentPackages, $resultPackages)
+    public function __construct(array $presentPackages, array $resultPackages)
     {
         $this->presentPackages = $presentPackages;
         $this->setResultPackageMaps($resultPackages);
@@ -60,7 +60,7 @@ class Transaction
     /**
      * @return OperationInterface[]
      */
-    public function getOperations()
+    public function getOperations(): array
     {
         return $this->operations;
     }
@@ -69,9 +69,9 @@ class Transaction
      * @param PackageInterface[] $resultPackages
      * @return void
      */
-    private function setResultPackageMaps($resultPackages)
+    private function setResultPackageMaps(array $resultPackages): void
     {
-        $packageSort = function (PackageInterface $a, PackageInterface $b) {
+        $packageSort = function (PackageInterface $a, PackageInterface $b): int {
             // sort alias packages by the same name behind their non alias version
             if ($a->getName() == $b->getName()) {
                 if ($a instanceof AliasPackage != $b instanceof AliasPackage) {
@@ -101,7 +101,7 @@ class Transaction
     /**
      * @return OperationInterface[]
      */
-    protected function calculateOperations()
+    protected function calculateOperations(): array
     {
         $operations = array();
 
@@ -218,7 +218,7 @@ class Transaction
      *
      * @return array<string, PackageInterface>
      */
-    protected function getRootPackages()
+    protected function getRootPackages(): array
     {
         $roots = $this->resultPackageMap;
 
@@ -244,7 +244,7 @@ class Transaction
     /**
      * @return PackageInterface[]
      */
-    protected function getProvidersInResult(Link $link)
+    protected function getProvidersInResult(Link $link): array
     {
         if (!isset($this->resultPackagesByName[$link->getTarget()])) {
             return array();
@@ -266,7 +266,7 @@ class Transaction
      * @param  OperationInterface[] $operations
      * @return OperationInterface[] reordered operation list
      */
-    private function movePluginsToFront(array $operations)
+    private function movePluginsToFront(array $operations): array
     {
         $dlModifyingPluginsNoDeps = array();
         $dlModifyingPluginsWithDeps = array();
@@ -289,7 +289,7 @@ class Transaction
             // is this a downloads modifying plugin or a dependency of one?
             if ($isDownloadsModifyingPlugin || count(array_intersect($package->getNames(), $dlModifyingPluginRequires))) {
                 // get the package's requires, but filter out any platform requirements
-                $requires = array_filter(array_keys($package->getRequires()), function ($req) {
+                $requires = array_filter(array_keys($package->getRequires()), function ($req): bool {
                     return !PlatformRepository::isPlatformPackage($req);
                 });
 
@@ -314,7 +314,7 @@ class Transaction
             // is this a plugin or a dependency of a plugin?
             if ($isPlugin || count(array_intersect($package->getNames(), $pluginRequires))) {
                 // get the package's requires, but filter out any platform requirements
-                $requires = array_filter(array_keys($package->getRequires()), function ($req) {
+                $requires = array_filter(array_keys($package->getRequires()), function ($req): bool {
                     return !PlatformRepository::isPlatformPackage($req);
                 });
 
@@ -343,7 +343,7 @@ class Transaction
      * @param  OperationInterface[] $operations
      * @return OperationInterface[] reordered operation list
      */
-    private function moveUninstallsToFront(array $operations)
+    private function moveUninstallsToFront(array $operations): array
     {
         $uninstOps = array();
         foreach ($operations as $idx => $op) {
