@@ -1,4 +1,14 @@
-<?php
+<?php declare(strict_types=1);
+
+/*
+ * This file is part of Composer.
+ *
+ * (c) Nils Adermann <naderman@naderman.de>
+ *     Jordi Boggiano <j.boggiano@seld.be>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
 
 namespace Composer\Filter\PlatformRequirementFilter;
 
@@ -9,7 +19,7 @@ final class PlatformRequirementFilterFactory
      *
      * @return PlatformRequirementFilterInterface
      */
-    public static function fromBoolOrList($boolOrList)
+    public static function fromBoolOrList($boolOrList): PlatformRequirementFilterInterface
     {
         if (is_bool($boolOrList)) {
             return $boolOrList ? self::ignoreAll() : self::ignoreNothing();
@@ -30,7 +40,7 @@ final class PlatformRequirementFilterFactory
     /**
      * @return PlatformRequirementFilterInterface
      */
-    public static function ignoreAll()
+    public static function ignoreAll(): PlatformRequirementFilterInterface
     {
         return new IgnoreAllPlatformRequirementFilter();
     }
@@ -38,7 +48,7 @@ final class PlatformRequirementFilterFactory
     /**
      * @return PlatformRequirementFilterInterface
      */
-    public static function ignoreNothing()
+    public static function ignoreNothing(): PlatformRequirementFilterInterface
     {
         return new IgnoreNothingPlatformRequirementFilter();
     }
