@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -71,7 +71,7 @@ class ConsoleIO extends BaseIO
      *
      * @return void
      */
-    public function enableDebugging($startTime)
+    public function enableDebugging(float $startTime)
     {
         $this->startTime = $startTime;
     }
@@ -97,7 +97,7 @@ class ConsoleIO extends BaseIO
      */
     public function isVerbose()
     {
-        return $this->output->getVerbosity() >= OutputInterface::VERBOSITY_VERBOSE;
+        return $this->output->isVerbose();
     }
 
     /**
@@ -105,7 +105,7 @@ class ConsoleIO extends BaseIO
      */
     public function isVeryVerbose()
     {
-        return $this->output->getVerbosity() >= OutputInterface::VERBOSITY_VERY_VERBOSE;
+        return $this->output->isVeryVerbose();
     }
 
     /**
@@ -113,13 +113,13 @@ class ConsoleIO extends BaseIO
      */
     public function isDebug()
     {
-        return $this->output->getVerbosity() >= OutputInterface::VERBOSITY_DEBUG;
+        return $this->output->isDebug();
     }
 
     /**
      * @inheritDoc
      */
-    public function write($messages, $newline = true, $verbosity = self::NORMAL)
+    public function write($messages, bool $newline = true, int $verbosity = self::NORMAL)
     {
         $this->doWrite($messages, $newline, false, $verbosity);
     }
@@ -127,7 +127,7 @@ class ConsoleIO extends BaseIO
     /**
      * @inheritDoc
      */
-    public function writeError($messages, $newline = true, $verbosity = self::NORMAL)
+    public function writeError($messages, bool $newline = true, int $verbosity = self::NORMAL)
     {
         $this->doWrite($messages, $newline, true, $verbosity);
     }
@@ -135,7 +135,7 @@ class ConsoleIO extends BaseIO
     /**
      * @inheritDoc
      */
-    public function writeRaw($messages, $newline = true, $verbosity = self::NORMAL)
+    public function writeRaw($messages, bool $newline = true, int $verbosity = self::NORMAL)
     {
         $this->doWrite($messages, $newline, false, $verbosity, true);
     }
@@ -143,7 +143,7 @@ class ConsoleIO extends BaseIO
     /**
      * @inheritDoc
      */
-    public function writeErrorRaw($messages, $newline = true, $verbosity = self::NORMAL)
+    public function writeErrorRaw($messages, bool $newline = true, int $verbosity = self::NORMAL)
     {
         $this->doWrite($messages, $newline, true, $verbosity, true);
     }
@@ -157,7 +157,7 @@ class ConsoleIO extends BaseIO
      *
      * @return void
      */
-    private function doWrite($messages, $newline, $stderr, $verbosity, $raw = false)
+    private function doWrite($messages, bool $newline, bool $stderr, int $verbosity, bool $raw = false): void
     {
         $sfVerbosity = $this->verbosityMap[$verbosity];
         if ($sfVerbosity > $this->output->getVerbosity()) {
@@ -175,7 +175,7 @@ class ConsoleIO extends BaseIO
         if (null !== $this->startTime) {
             $memoryUsage = memory_get_usage() / 1024 / 1024;
             $timeSpent = microtime(true) - $this->startTime;
-            $messages = array_map(function ($message) use ($memoryUsage, $timeSpent) {
+            $messages = array_map(function ($message) use ($memoryUsage, $timeSpent): string {
                 return sprintf('[%.1fMiB/%.2fs] %s', $memoryUsage, $timeSpent, $message);
             }, (array) $messages);
         }
@@ -194,7 +194,7 @@ class ConsoleIO extends BaseIO
     /**
      * @inheritDoc
      */
-    public function overwrite($messages, $newline = true, $size = null, $verbosity = self::NORMAL)
+    public function overwrite($messages, bool $newline = true, ?int $size = null, int $verbosity = self::NORMAL)
     {
         $this->doOverwrite($messages, $newline, $size, false, $verbosity);
     }
@@ -202,7 +202,7 @@ class ConsoleIO extends BaseIO
     /**
      * @inheritDoc
      */
-    public function overwriteError($messages, $newline = true, $size = null, $verbosity = self::NORMAL)
+    public function overwriteError($messages, bool $newline = true, ?int $size = null, int $verbosity = self::NORMAL)
     {
         $this->doOverwrite($messages, $newline, $size, true, $verbosity);
     }
@@ -216,7 +216,7 @@ class ConsoleIO extends BaseIO
      *
      * @return void
      */
-    private function doOverwrite($messages, $newline, $size, $stderr, $verbosity)
+    private function doOverwrite($messages, bool $newline, ?int $size, bool $stderr, int $verbosity): void
     {
         // messages can be an array, let's convert it to string anyway
         $messages = implode($newline ? "\n" : '', (array) $messages);
@@ -258,7 +258,7 @@ class ConsoleIO extends BaseIO
      * @param  int         $max
      * @return ProgressBar
      */
-    public function getProgressBar($max = 0)
+    public function getProgressBar(int $max = 0)
     {
         return new ProgressBar($this->getErrorOutput(), $max);
     }
@@ -345,7 +345,7 @@ class ConsoleIO extends BaseIO
     /**
      * @return OutputInterface
      */
-    private function getErrorOutput()
+    private function getErrorOutput(): OutputInterface
     {
         if ($this->output instanceof ConsoleOutputInterface) {
             return $this->output->getErrorOutput();
