@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -70,12 +70,12 @@ use Composer\Util\Platform;
  */
 class Installer
 {
-    const ERROR_NONE = 0; // no error/success state
-    const ERROR_GENERIC_FAILURE = 1;
-    const ERROR_NO_LOCK_FILE_FOR_PARTIAL_UPDATE = 3;
-    const ERROR_LOCK_FILE_INVALID = 4;
+    public const ERROR_NONE = 0; // no error/success state
+    public const ERROR_GENERIC_FAILURE = 1;
+    public const ERROR_NO_LOCK_FILE_FOR_PARTIAL_UPDATE = 3;
+    public const ERROR_LOCK_FILE_INVALID = 4;
     // used/declared in SolverProblemsException, carried over here for completeness
-    const ERROR_DEPENDENCY_RESOLUTION_FAILED = 2;
+    public const ERROR_DEPENDENCY_RESOLUTION_FAILED = 2;
 
     /**
      * @var IOInterface
@@ -226,7 +226,7 @@ class Installer
      * @return int        0 on success or a positive error code on failure
      * @phpstan-return self::ERROR_*
      */
-    public function run()
+    public function run(): int
     {
         // Disable GC to save CPU cycles, as the dependency solver can create hundreds of thousands
         // of PHP objects, the GC can spend quite some time walking the tree of references looking
@@ -386,7 +386,7 @@ class Installer
      * @return int
      * @phpstan-return self::ERROR_*
      */
-    protected function doUpdate(InstalledRepositoryInterface $localRepo, $doInstall)
+    protected function doUpdate(InstalledRepositoryInterface $localRepo, bool $doInstall): int
     {
         $platformRepo = $this->createPlatformRepo(true);
         $aliases = $this->getRootAliases(true);
@@ -473,6 +473,11 @@ class Installer
             return $exitCode;
         }
 
+        // exists as of composer/semver 3.3.0
+        if (method_exists('Composer\Semver\CompilingMatcher', 'clear')) { // @phpstan-ignore-line
+            \Composer\Semver\CompilingMatcher::clear();
+        }
+
         // write lock
         $platformReqs = $this->extractPlatformRequirements($this->package->getRequires());
         $platformDevReqs = $this->extractPlatformRequirements($this->package->getDevRequires());
@@ -502,27 +507,29 @@ class Installer
                 }
             }
 
-            $this->io->writeError(sprintf(
-                "<info>Lock file operations: %d install%s, %d update%s, %d removal%s</info>",
-                count($installNames),
-                1 === count($installNames) ? '' : 's',
-                count($updateNames),
-                1 === count($updateNames) ? '' : 's',
-                count($uninstalls),
-                1 === count($uninstalls) ? '' : 's'
-            ));
-            if ($installNames) {
-                $this->io->writeError("Installs: ".implode(', ', $installNames), true, IOInterface::VERBOSE);
-            }
-            if ($updateNames) {
-                $this->io->writeError("Updates: ".implode(', ', $updateNames), true, IOInterface::VERBOSE);
-            }
-            if ($uninstalls) {
-                $this->io->writeError("Removals: ".implode(', ', $uninstallNames), true, IOInterface::VERBOSE);
+            if ($this->config->get('lock')) {
+                $this->io->writeError(sprintf(
+                    "<info>Lock file operations: %d install%s, %d update%s, %d removal%s</info>",
+                    count($installNames),
+                    1 === count($installNames) ? '' : 's',
+                    count($updateNames),
+                    1 === count($updateNames) ? '' : 's',
+                    count($uninstalls),
+                    1 === count($uninstalls) ? '' : 's'
+                ));
+                if ($installNames) {
+                    $this->io->writeError("Installs: ".implode(', ', $installNames), true, IOInterface::VERBOSE);
+                }
+                if ($updateNames) {
+                    $this->io->writeError("Updates: ".implode(', ', $updateNames), true, IOInterface::VERBOSE);
+                }
+                if ($uninstalls) {
+                    $this->io->writeError("Removals: ".implode(', ', $uninstallNames), true, IOInterface::VERBOSE);
+                }
             }
         }
 
-        $sortByName = function ($a, $b) {
+        $sortByName = function ($a, $b): int {
             if ($a instanceof UpdateOperation) {
                 $a = $a->getTargetPackage()->getName();
             } else {
@@ -545,8 +552,8 @@ class Installer
                 $this->suggestedPackagesReporter->addSuggestionsFromPackage($operation->getPackage());
             }
 
-            // output op, but alias op only in debug verbosity
-            if (false === strpos($operation->getOperationType(), 'Alias') || $this->io->isDebug()) {
+            // output op if lock file is enabled, but alias op only in debug verbosity
+            if ($this->config->get('lock') && (false === strpos($operation->getOperationType(), 'Alias') || $this->io->isDebug())) {
                 $this->io->writeError('  - ' . $operation->show(true));
             }
         }
@@ -597,7 +604,7 @@ class Installer
      * @phpstan-param list<array{package: string, version: string, alias: string, alias_normalized: string}> $aliases
      * @phpstan-return self::ERROR_*
      */
-    protected function extractDevPackages(LockTransaction $lockTransaction, PlatformRepository $platformRepo, array $aliases, PolicyInterface $policy, LockArrayRepository $lockedRepository = null)
+    protected function extractDevPackages(LockTransaction $lockTransaction, PlatformRepository $platformRepo, array $aliases, PolicyInterface $policy, LockArrayRepository $lockedRepository = null): int
     {
         if (!$this->package->getDevRequires()) {
             return 0;
@@ -648,9 +655,11 @@ class Installer
      * @return int                          exit code
      * @phpstan-return self::ERROR_*
      */
-    protected function doInstall(InstalledRepositoryInterface $localRepo, $alreadySolved = false)
+    protected function doInstall(InstalledRepositoryInterface $localRepo, bool $alreadySolved = false): int
     {
-        $this->io->writeError('<info>Installing dependencies from lock file'.($this->devMode ? ' (including require-dev)' : '').'</info>');
+        if ($this->config->get('lock')) {
+            $this->io->writeError('<info>Installing dependencies from lock file'.($this->devMode ? ' (including require-dev)' : '').'</info>');
+        }
 
         $lockedRepository = $this->locker->getLockedRepository($this->devMode);
 
@@ -769,7 +778,7 @@ class Installer
      *
      * @return PlatformRepository
      */
-    protected function createPlatformRepo($forUpdate)
+    protected function createPlatformRepo(bool $forUpdate): PlatformRepository
     {
         if ($forUpdate) {
             $platformOverrides = $this->config->get('platform') ?: array();
@@ -789,7 +798,7 @@ class Installer
      *
      * @phpstan-param list<array{package: string, version: string, alias: string, alias_normalized: string}> $rootAliases
      */
-    private function createRepositorySet($forUpdate, PlatformRepository $platformRepo, array $rootAliases = array(), $lockedRepository = null)
+    private function createRepositorySet(bool $forUpdate, PlatformRepository $platformRepo, array $rootAliases = array(), ?RepositoryInterface $lockedRepository = null): RepositorySet
     {
         if ($forUpdate) {
             $minimumStability = $this->package->getMinimumStability();
@@ -858,7 +867,7 @@ class Installer
      *
      * @return DefaultPolicy
      */
-    private function createPolicy($forUpdate)
+    private function createPolicy(bool $forUpdate): DefaultPolicy
     {
         $preferStable = null;
         $preferLowest = null;
@@ -882,7 +891,7 @@ class Installer
      * @param RootPackageInterface&BasePackage $rootPackage
      * @return Request
      */
-    private function createRequest(RootPackageInterface $rootPackage, PlatformRepository $platformRepo, LockArrayRepository $lockedRepository = null)
+    private function createRequest(RootPackageInterface $rootPackage, PlatformRepository $platformRepo, LockArrayRepository $lockedRepository = null): Request
     {
         $request = new Request($lockedRepository);
 
@@ -919,7 +928,7 @@ class Installer
      *
      * @return void
      */
-    private function requirePackagesForUpdate(Request $request, LockArrayRepository $lockedRepository = null, $includeDevRequires = true)
+    private function requirePackagesForUpdate(Request $request, LockArrayRepository $lockedRepository = null, bool $includeDevRequires = true): void
     {
         // if we're updating mirrors we want to keep exactly the same versions installed which are in the lock file, but we want current remote metadata
         if ($this->updateMirrors) {
@@ -953,7 +962,7 @@ class Installer
      *
      * @phpstan-return list<array{package: string, version: string, alias: string, alias_normalized: string}>
      */
-    private function getRootAliases($forUpdate)
+    private function getRootAliases(bool $forUpdate): array
     {
         if ($forUpdate) {
             $aliases = $this->package->getAliases();
@@ -969,7 +978,7 @@ class Installer
      *
      * @return array<string, string>
      */
-    private function extractPlatformRequirements(array $links)
+    private function extractPlatformRequirements(array $links): array
     {
         $platformReqs = array();
         foreach ($links as $link) {
@@ -988,7 +997,7 @@ class Installer
      *
      * @return void
      */
-    private function mockLocalRepositories(RepositoryManager $rm)
+    private function mockLocalRepositories(RepositoryManager $rm): void
     {
         $packages = array();
         foreach ($rm->getLocalRepository()->getPackages() as $package) {
@@ -1009,7 +1018,7 @@ class Installer
     /**
      * @return PoolOptimizer|null
      */
-    private function createPoolOptimizer(PolicyInterface $policy)
+    private function createPoolOptimizer(PolicyInterface $policy): ?PoolOptimizer
     {
         // Not the best architectural decision here, would need to be able
         // to configure from the outside of Installer but this is only
@@ -1030,7 +1039,7 @@ class Installer
      * @param  Composer    $composer
      * @return Installer
      */
-    public static function create(IOInterface $io, Composer $composer)
+    public static function create(IOInterface $io, Composer $composer): self
     {
         return new static(
             $io,
@@ -1049,7 +1058,7 @@ class Installer
      * @param  RepositoryInterface $additionalFixedRepository
      * @return $this
      */
-    public function setAdditionalFixedRepository(RepositoryInterface $additionalFixedRepository)
+    public function setAdditionalFixedRepository(RepositoryInterface $additionalFixedRepository): self
     {
         $this->additionalFixedRepository = $additionalFixedRepository;
 
@@ -1062,7 +1071,7 @@ class Installer
      * @param  bool      $dryRun
      * @return Installer
      */
-    public function setDryRun($dryRun = true)
+    public function setDryRun(bool $dryRun = true): self
     {
         $this->dryRun = (bool) $dryRun;
 
@@ -1074,7 +1083,7 @@ class Installer
      *
      * @return bool
      */
-    public function isDryRun()
+    public function isDryRun(): bool
     {
         return $this->dryRun;
     }
@@ -1085,7 +1094,7 @@ class Installer
      * @param  bool      $preferSource
      * @return Installer
      */
-    public function setPreferSource($preferSource = true)
+    public function setPreferSource(bool $preferSource = true): self
     {
         $this->preferSource = (bool) $preferSource;
 
@@ -1098,7 +1107,7 @@ class Installer
      * @param  bool      $preferDist
      * @return Installer
      */
-    public function setPreferDist($preferDist = true)
+    public function setPreferDist(bool $preferDist = true): self
     {
         $this->preferDist = (bool) $preferDist;
 
@@ -1111,7 +1120,7 @@ class Installer
      * @param  bool      $optimizeAutoloader
      * @return Installer
      */
-    public function setOptimizeAutoloader($optimizeAutoloader)
+    public function setOptimizeAutoloader(bool $optimizeAutoloader): self
     {
         $this->optimizeAutoloader = (bool) $optimizeAutoloader;
         if (!$this->optimizeAutoloader) {
@@ -1130,7 +1139,7 @@ class Installer
      * @param  bool      $classMapAuthoritative
      * @return Installer
      */
-    public function setClassMapAuthoritative($classMapAuthoritative)
+    public function setClassMapAuthoritative(bool $classMapAuthoritative): self
     {
         $this->classMapAuthoritative = (bool) $classMapAuthoritative;
         if ($this->classMapAuthoritative) {
@@ -1148,7 +1157,7 @@ class Installer
      * @param  string|null $apcuAutoloaderPrefix
      * @return Installer
      */
-    public function setApcuAutoloader($apcuAutoloader, $apcuAutoloaderPrefix = null)
+    public function setApcuAutoloader(bool $apcuAutoloader, ?string $apcuAutoloaderPrefix = null): self
     {
         $this->apcuAutoloader = $apcuAutoloader;
         $this->apcuAutoloaderPrefix = $apcuAutoloaderPrefix;
@@ -1162,7 +1171,7 @@ class Installer
      * @param  bool      $update
      * @return Installer
      */
-    public function setUpdate($update)
+    public function setUpdate(bool $update): self
     {
         $this->update = (bool) $update;
 
@@ -1175,7 +1184,7 @@ class Installer
      * @param  bool      $install
      * @return Installer
      */
-    public function setInstall($install)
+    public function setInstall(bool $install): self
     {
         $this->install = (bool) $install;
 
@@ -1188,7 +1197,7 @@ class Installer
      * @param  bool      $devMode
      * @return Installer
      */
-    public function setDevMode($devMode = true)
+    public function setDevMode(bool $devMode = true): self
     {
         $this->devMode = (bool) $devMode;
 
@@ -1203,7 +1212,7 @@ class Installer
      * @param  bool      $dumpAutoloader
      * @return Installer
      */
-    public function setDumpAutoloader($dumpAutoloader = true)
+    public function setDumpAutoloader(bool $dumpAutoloader = true): self
     {
         $this->dumpAutoloader = (bool) $dumpAutoloader;
 
@@ -1219,7 +1228,7 @@ class Installer
      * @return Installer
      * @deprecated Use setRunScripts(false) on the EventDispatcher instance being injected instead
      */
-    public function setRunScripts($runScripts = true)
+    public function setRunScripts(bool $runScripts = true): self
     {
         $this->runScripts = (bool) $runScripts;
 
@@ -1232,7 +1241,7 @@ class Installer
      * @param  Config    $config
      * @return Installer
      */
-    public function setConfig(Config $config)
+    public function setConfig(Config $config): self
     {
         $this->config = $config;
 
@@ -1245,7 +1254,7 @@ class Installer
      * @param  bool      $verbose
      * @return Installer
      */
-    public function setVerbose($verbose = true)
+    public function setVerbose(bool $verbose = true): self
     {
         $this->verbose = (bool) $verbose;
 
@@ -1257,7 +1266,7 @@ class Installer
      *
      * @return bool
      */
-    public function isVerbose()
+    public function isVerbose(): bool
     {
         return $this->verbose;
     }
@@ -1275,7 +1284,7 @@ class Installer
      *
      * @deprecated use setPlatformRequirementFilter instead
      */
-    public function setIgnorePlatformRequirements($ignorePlatformReqs)
+    public function setIgnorePlatformRequirements($ignorePlatformReqs): self
     {
         trigger_error('Installer::setIgnorePlatformRequirements is deprecated since Composer 2.2, use setPlatformRequirementFilter instead.', E_USER_DEPRECATED);
 
@@ -1286,7 +1295,7 @@ class Installer
      * @param PlatformRequirementFilterInterface $platformRequirementFilter
      * @return Installer
      */
-    public function setPlatformRequirementFilter(PlatformRequirementFilterInterface $platformRequirementFilter)
+    public function setPlatformRequirementFilter(PlatformRequirementFilterInterface $platformRequirementFilter): self
     {
         $this->platformRequirementFilter = $platformRequirementFilter;
 
@@ -1299,7 +1308,7 @@ class Installer
      * @param  bool      $updateMirrors
      * @return Installer
      */
-    public function setUpdateMirrors($updateMirrors)
+    public function setUpdateMirrors(bool $updateMirrors): self
     {
         $this->updateMirrors = $updateMirrors;
 
@@ -1314,7 +1323,7 @@ class Installer
      *
      * @return Installer
      */
-    public function setUpdateAllowList(array $packages)
+    public function setUpdateAllowList(array $packages): self
     {
         $this->updateAllowList = array_flip(array_map('strtolower', $packages));
 
@@ -1330,7 +1339,7 @@ class Installer
      * @param  int       $updateAllowTransitiveDependencies One of the UPDATE_ constants on the Request class
      * @return Installer
      */
-    public function setUpdateAllowTransitiveDependencies($updateAllowTransitiveDependencies)
+    public function setUpdateAllowTransitiveDependencies(int $updateAllowTransitiveDependencies): self
     {
         if (!in_array($updateAllowTransitiveDependencies, array(Request::UPDATE_ONLY_LISTED, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS_NO_ROOT_REQUIRE, Request::UPDATE_LISTED_WITH_TRANSITIVE_DEPS), true)) {
             throw new \RuntimeException("Invalid value for updateAllowTransitiveDependencies supplied");
@@ -1347,7 +1356,7 @@ class Installer
      * @param  bool      $preferStable
      * @return Installer
      */
-    public function setPreferStable($preferStable = true)
+    public function setPreferStable(bool $preferStable = true): self
     {
         $this->preferStable = (bool) $preferStable;
 
@@ -1360,7 +1369,7 @@ class Installer
      * @param  bool      $preferLowest
      * @return Installer
      */
-    public function setPreferLowest($preferLowest = true)
+    public function setPreferLowest(bool $preferLowest = true): self
     {
         $this->preferLowest = (bool) $preferLowest;
 
@@ -1375,7 +1384,7 @@ class Installer
      * @param  bool      $writeLock
      * @return Installer
      */
-    public function setWriteLock($writeLock = true)
+    public function setWriteLock(bool $writeLock = true): self
     {
         $this->writeLock = (bool) $writeLock;
 
@@ -1390,7 +1399,7 @@ class Installer
      * @param  bool      $executeOperations
      * @return Installer
      */
-    public function setExecuteOperations($executeOperations = true)
+    public function setExecuteOperations(bool $executeOperations = true): self
     {
         $this->executeOperations = (bool) $executeOperations;
 
@@ -1406,7 +1415,7 @@ class Installer
      *
      * @return Installer
      */
-    public function disablePlugins()
+    public function disablePlugins(): self
     {
         $this->installationManager->disablePlugins();
 
@@ -1417,7 +1426,7 @@ class Installer
      * @param  SuggestedPackagesReporter $suggestedPackagesReporter
      * @return Installer
      */
-    public function setSuggestedPackagesReporter(SuggestedPackagesReporter $suggestedPackagesReporter)
+    public function setSuggestedPackagesReporter(SuggestedPackagesReporter $suggestedPackagesReporter): self
     {
         $this->suggestedPackagesReporter = $suggestedPackagesReporter;
 
