@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -12,6 +12,7 @@
 
 namespace Composer\Installer;
 
+use React\Promise\PromiseInterface;
 use Composer\Package\PackageInterface;
 use Composer\Downloader\DownloadManager;
 use Composer\Repository\InstalledRepositoryInterface;
@@ -35,7 +36,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @param string $installPath
      */
-    public function __construct($installPath, DownloadManager $dm, Filesystem $fs)
+    public function __construct(string $installPath, DownloadManager $dm, Filesystem $fs)
     {
         $this->installPath = rtrim(strtr($installPath, '\\', '/'), '/').'/';
         $this->downloadManager = $dm;
@@ -48,7 +49,7 @@ class ProjectInstaller implements InstallerInterface
      * @param  string $packageType
      * @return bool
      */
-    public function supports($packageType)
+    public function supports(string $packageType): bool
     {
         return true;
     }
@@ -56,7 +57,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function isInstalled(InstalledRepositoryInterface $repo, PackageInterface $package)
+    public function isInstalled(InstalledRepositoryInterface $repo, PackageInterface $package): bool
     {
         return false;
     }
@@ -64,7 +65,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function download(PackageInterface $package, PackageInterface $prevPackage = null)
+    public function download(PackageInterface $package, PackageInterface $prevPackage = null): ?PromiseInterface
     {
         $installPath = $this->installPath;
         if (file_exists($installPath) && !$this->filesystem->isDirEmpty($installPath)) {
@@ -80,7 +81,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function prepare($type, PackageInterface $package, PackageInterface $prevPackage = null)
+    public function prepare($type, PackageInterface $package, PackageInterface $prevPackage = null): ?PromiseInterface
     {
         return $this->downloadManager->prepare($type, $package, $this->installPath, $prevPackage);
     }
@@ -88,7 +89,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function cleanup($type, PackageInterface $package, PackageInterface $prevPackage = null)
+    public function cleanup($type, PackageInterface $package, PackageInterface $prevPackage = null): ?PromiseInterface
     {
         return $this->downloadManager->cleanup($type, $package, $this->installPath, $prevPackage);
     }
@@ -96,7 +97,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function install(InstalledRepositoryInterface $repo, PackageInterface $package)
+    public function install(InstalledRepositoryInterface $repo, PackageInterface $package): ?PromiseInterface
     {
         return $this->downloadManager->install($package, $this->installPath);
     }
@@ -104,7 +105,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function update(InstalledRepositoryInterface $repo, PackageInterface $initial, PackageInterface $target)
+    public function update(InstalledRepositoryInterface $repo, PackageInterface $initial, PackageInterface $target): ?PromiseInterface
     {
         throw new \InvalidArgumentException("not supported");
     }
@@ -112,7 +113,7 @@ class ProjectInstaller implements InstallerInterface
     /**
      * @inheritDoc
      */
-    public function uninstall(InstalledRepositoryInterface $repo, PackageInterface $package)
+    public function uninstall(InstalledRepositoryInterface $repo, PackageInterface $package): ?PromiseInterface
     {
         throw new \InvalidArgumentException("not supported");
     }
@@ -123,7 +124,7 @@ class ProjectInstaller implements InstallerInterface
      * @param  PackageInterface $package
      * @return string           path
      */
-    public function getInstallPath(PackageInterface $package)
+    public function getInstallPath(PackageInterface $package): string
     {
         return $this->installPath;
     }
