@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,12 +17,13 @@ use PharData;
 
 class ArchivableFilesFilter extends FilterIterator
 {
+    /** @var string[] */
     private $dirs = array();
 
     /**
      * @return bool true if the current element is acceptable, otherwise false.
      */
-    public function accept()
+    public function accept(): bool
     {
         $file = $this->getInnerIterator()->current();
         if ($file->isDir()) {
@@ -34,7 +35,12 @@ class ArchivableFilesFilter extends FilterIterator
         return true;
     }
 
-    public function addEmptyDir(PharData $phar, $sources)
+    /**
+     * @param string $sources
+     *
+     * @return void
+     */
+    public function addEmptyDir(PharData $phar, string $sources): void
     {
         foreach ($this->dirs as $filepath) {
             $localname = str_replace($sources . "/", '', $filepath);
