@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -15,7 +15,12 @@ namespace Composer\Package;
 /**
  * Defines additional fields that are only needed for the root package
  *
+ * PackageInterface & derivatives are considered internal, you may use them in type hints but extending/implementing them is not recommended and not supported. Things may change without notice.
+ *
  * @author Jordi Boggiano <j.boggiano@seld.be>
+ *
+ * @phpstan-import-type AutoloadRules from PackageInterface
+ * @phpstan-import-type DevAutoloadRules from PackageInterface
  */
 interface RootPackageInterface extends CompletePackageInterface
 {
@@ -24,14 +29,14 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return array<array{package: string, version: string, alias: string, alias_normalized: string}>
      */
-    public function getAliases();
+    public function getAliases(): array;
 
     /**
      * Returns the minimum stability of the package
      *
      * @return string
      */
-    public function getMinimumStability();
+    public function getMinimumStability(): string;
 
     /**
      * Returns the stability flags to apply to dependencies
@@ -40,7 +45,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return array<string, BasePackage::STABILITY_*>
      */
-    public function getStabilityFlags();
+    public function getStabilityFlags(): array;
 
     /**
      * Returns a set of package names and source references that must be enforced on them
@@ -49,21 +54,21 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return array<string, string>
      */
-    public function getReferences();
+    public function getReferences(): array;
 
     /**
      * Returns true if the root package prefers picking stable packages over unstable ones
      *
      * @return bool
      */
-    public function getPreferStable();
+    public function getPreferStable(): bool;
 
     /**
      * Returns the root package's configuration
      *
      * @return mixed[]
      */
-    public function getConfig();
+    public function getConfig(): array;
 
     /**
      * Set the required packages
@@ -72,7 +77,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setRequires(array $requires);
+    public function setRequires(array $requires): void;
 
     /**
      * Set the recommended packages
@@ -81,7 +86,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setDevRequires(array $devRequires);
+    public function setDevRequires(array $devRequires): void;
 
     /**
      * Set the conflicting packages
@@ -90,7 +95,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setConflicts(array $conflicts);
+    public function setConflicts(array $conflicts): void;
 
     /**
      * Set the provided virtual packages
@@ -99,7 +104,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setProvides(array $provides);
+    public function setProvides(array $provides): void;
 
     /**
      * Set the packages this one replaces
@@ -108,34 +113,27 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setReplaces(array $replaces);
-
-    /**
-     * Set the repositories
-     *
-     * @param mixed[] $repositories
-     *
-     * @return void
-     */
-    public function setRepositories(array $repositories);
+    public function setReplaces(array $replaces): void;
 
     /**
      * Set the autoload mapping
      *
-     * @param array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} $autoload Mapping of autoloading rules
+     * @param array $autoload Mapping of autoloading rules
+     * @phpstan-param AutoloadRules $autoload
      *
      * @return void
      */
-    public function setAutoload(array $autoload);
+    public function setAutoload(array $autoload): void;
 
     /**
      * Set the dev autoload mapping
      *
-     * @param array{psr-0?: array<string, string|string[]>, psr-4?: array<string, string|string[]>, classmap?: list<string>, files?: list<string>} $devAutoload Mapping of dev autoloading rules
+     * @param array $devAutoload Mapping of dev autoloading rules
+     * @phpstan-param DevAutoloadRules $devAutoload
      *
      * @return void
      */
-    public function setDevAutoload(array $devAutoload);
+    public function setDevAutoload(array $devAutoload): void;
 
     /**
      * Set the stabilityFlags
@@ -144,7 +142,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setStabilityFlags(array $stabilityFlags);
+    public function setStabilityFlags(array $stabilityFlags): void;
 
     /**
      * Set the minimumStability
@@ -153,7 +151,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setMinimumStability($minimumStability);
+    public function setMinimumStability(string $minimumStability): void;
 
     /**
      * Set the preferStable
@@ -162,7 +160,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setPreferStable($preferStable);
+    public function setPreferStable(bool $preferStable): void;
 
     /**
      * Set the config
@@ -171,7 +169,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setConfig(array $config);
+    public function setConfig(array $config): void;
 
     /**
      * Set the references
@@ -180,7 +178,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setReferences(array $references);
+    public function setReferences(array $references): void;
 
     /**
      * Set the aliases
@@ -189,7 +187,7 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setAliases(array $aliases);
+    public function setAliases(array $aliases): void;
 
     /**
      * Set the suggested packages
@@ -198,12 +196,12 @@ interface RootPackageInterface extends CompletePackageInterface
      *
      * @return void
      */
-    public function setSuggests(array $suggests);
+    public function setSuggests(array $suggests): void;
 
     /**
      * @param mixed[] $extra
      *
      * @return void
      */
-    public function setExtra(array $extra);
+    public function setExtra(array $extra): void;
 }
