@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -18,6 +18,7 @@ use Composer\IO\IOInterface;
 use Composer\Pcre\Preg;
 use Composer\Util\ProcessExecutor;
 use Composer\Util\Perforce;
+use Composer\Util\Http\Response;
 
 /**
  * @author Matt Whittom <Matt.Whittom@veteransunited.com>
@@ -34,7 +35,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function initialize()
+    public function initialize(): void
     {
         $this->depot = $this->repoConfig['depot'];
         $this->branch = '';
@@ -55,13 +56,13 @@ class PerforceDriver extends VcsDriver
      *
      * @return void
      */
-    private function initPerforce($repoConfig)
+    private function initPerforce(array $repoConfig): void
     {
         if (!empty($this->perforce)) {
             return;
         }
 
-        if (!Cache::isUsable((string) $this->config->get('cache-vcs-dir'))) {
+        if (!Cache::isUsable($this->config->get('cache-vcs-dir'))) {
             throw new \RuntimeException('PerforceDriver requires a usable cache directory, and it looks like you set it to be disabled');
         }
 
@@ -72,7 +73,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getFileContent($file, $identifier)
+    public function getFileContent(string $file, string $identifier): ?string
     {
         return $this->perforce->getFileContent($file, $identifier);
     }
@@ -80,7 +81,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getChangeDate($identifier)
+    public function getChangeDate(string $identifier): ?\DateTimeImmutable
     {
         return null;
     }
@@ -88,7 +89,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getRootIdentifier()
+    public function getRootIdentifier(): string
     {
         return $this->branch;
     }
@@ -96,7 +97,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getBranches()
+    public function getBranches(): array
     {
         return $this->perforce->getBranches();
     }
@@ -104,7 +105,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getTags()
+    public function getTags(): array
     {
         return $this->perforce->getTags();
     }
@@ -112,7 +113,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getDist($identifier)
+    public function getDist(string $identifier): ?array
     {
         return null;
     }
@@ -120,7 +121,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getSource($identifier)
+    public function getSource(string $identifier): array
     {
         return array(
             'type' => 'perforce',
@@ -133,7 +134,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getUrl()
+    public function getUrl(): string
     {
         return $this->url;
     }
@@ -141,7 +142,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function hasComposerFile($identifier)
+    public function hasComposerFile(string $identifier): bool
     {
         $composerInfo = $this->perforce->getComposerInformation('//' . $this->depot . '/' . $identifier);
 
@@ -151,7 +152,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function getContents($url)
+    public function getContents(string $url): Response
     {
         throw new \BadMethodCallException('Not implemented/used in PerforceDriver');
     }
@@ -159,7 +160,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public static function supports(IOInterface $io, Config $config, $url, $deep = false)
+    public static function supports(IOInterface $io, Config $config, string $url, bool $deep = false): bool
     {
         if ($deep || Preg::isMatch('#\b(perforce|p4)\b#i', $url)) {
             return Perforce::checkServerExists($url, new ProcessExecutor($io));
@@ -171,7 +172,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @inheritDoc
      */
-    public function cleanup()
+    public function cleanup(): void
     {
         $this->perforce->cleanupClientSpec();
         $this->perforce = null;
@@ -180,7 +181,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @return string
      */
-    public function getDepot()
+    public function getDepot(): string
     {
         return $this->depot;
     }
@@ -188,7 +189,7 @@ class PerforceDriver extends VcsDriver
     /**
      * @return string
      */
-    public function getBranch()
+    public function getBranch(): string
     {
         return $this->branch;
     }
