@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -37,11 +37,11 @@ class AuthHelper
 
     /**
      * @param string      $origin
-     * @param string|bool $storeAuth
+     * @param 'prompt'|bool $storeAuth
      *
      * @return void
      */
-    public function storeAuth($origin, $storeAuth)
+    public function storeAuth(string $origin, $storeAuth): void
     {
         $store = false;
         $configSource = $this->config->getAuthConfigSource();
@@ -50,7 +50,7 @@ class AuthHelper
         } elseif ($storeAuth === 'prompt') {
             $answer = $this->io->askAndValidate(
                 'Do you want to store credentials for '.$origin.' in '.$configSource->getName().' ? [Yn] ',
-                function ($value) {
+                function ($value): string {
                     $input = strtolower(substr(trim($value), 0, 1));
                     if (in_array($input, array('y','n'))) {
                         return $input;
@@ -80,11 +80,11 @@ class AuthHelper
      * @param  string|null $reason     a message/description explaining why this was called
      * @param  string[]    $headers
      * @param  int         $retryCount the amount of retries already done on this URL
-     * @return array|null  containing retry (bool) and storeAuth (string|bool) keys, if retry is true the request should be
+     * @return array       containing retry (bool) and storeAuth (string|bool) keys, if retry is true the request should be
      *                                retried, if storeAuth is true then on a successful retry the authentication should be persisted to auth.json
-     * @phpstan-return ?array{retry: bool, storeAuth: string|bool}
+     * @phpstan-return array{retry: bool, storeAuth: 'prompt'|bool}
      */
-    public function promptAuthIfNeeded($url, $origin, $statusCode, $reason = null, $headers = array(), $retryCount = 0)
+    public function promptAuthIfNeeded(string $url, string $origin, int $statusCode, ?string $reason = null, array $headers = array(), int $retryCount = 0): array
     {
         $storeAuth = false;
 
@@ -186,15 +186,15 @@ class AuthHelper
         } else {
             // 404s are only handled for github
             if ($statusCode === 404) {
-                return null;
+                return ['retry' => false, 'storeAuth' => false];
             }
 
             // fail if the console is not interactive
             if (!$this->io->isInteractive()) {
                 if ($statusCode === 401) {
-                    $message = "The '" . $url . "' URL required authentication.\nYou must be using the interactive console to authenticate";
+                    $message = "The '" . $url . "' URL required authentication (HTTP 401).\nYou must be using the interactive console to authenticate";
                 } elseif ($statusCode === 403) {
-                    $message = "The '" . $url . "' URL could not be accessed: " . $reason;
+                    $message = "The '" . $url . "' URL could not be accessed (HTTP 403): " . $reason;
                 } else {
                     $message = "Unknown error code '" . $statusCode . "', reason: " . $reason;
                 }
@@ -210,7 +210,7 @@ class AuthHelper
                     return array('retry' => true, 'storeAuth' => false);
                 }
 
-                throw new TransportException("Invalid credentials for '" . $url . "', aborting.", $statusCode);
+                throw new TransportException("Invalid credentials (HTTP $statusCode) for '$url', aborting.", $statusCode);
             }
 
             $this->io->writeError('    Authentication required (<info>'.$origin.'</info>):');
@@ -230,7 +230,7 @@ class AuthHelper
      *
      * @return string[] updated headers array
      */
-    public function addAuthenticationHeader(array $headers, $origin, $url)
+    public function addAuthenticationHeader(array $headers, string $origin, string $url): array
     {
         if ($this->io->hasAuthentication($origin)) {
             $authenticationDisplayMessage = null;
@@ -287,7 +287,7 @@ class AuthHelper
      *
      * @return bool Whether the given URL is a public BitBucket download which requires no authentication.
      */
-    public function isPublicBitBucketDownload($urlToBitBucketFile)
+    public function isPublicBitBucketDownload(string $urlToBitBucketFile): bool
     {
         $domain = parse_url($urlToBitBucketFile, PHP_URL_HOST);
         if (strpos($domain, 'bitbucket.org') === false) {
