@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -55,7 +55,7 @@ class GitLab
      *
      * @return bool true on success
      */
-    public function authorizeOAuth($originUrl)
+    public function authorizeOAuth(string $originUrl): bool
     {
         // before composer 1.9, origin URLs had no port number in them
         $bcOriginUrl = Preg::replace('{:\d+}', '', $originUrl);
@@ -90,9 +90,16 @@ class GitLab
         }
 
         if (isset($token)) {
-            $username = is_array($token) && array_key_exists("username", $token) ? $token["username"] : $token;
-            $password = is_array($token) && array_key_exists("token", $token) ? $token["token"] : 'private-token';
-            $this->io->setAuthentication($originUrl, $username, $password);
+            $username = is_array($token) ? $token["username"] : $token;
+            $password = is_array($token) ? $token["token"] : 'private-token';
+
+            // Composer expects the GitLab token to be stored as username and 'private-token' or 'gitlab-ci-token' to be stored as password
+            // Detect cases where this is reversed and resolve automatically resolve it
+            if (in_array($username, array('private-token', 'gitlab-ci-token',  'oauth2'), true)) {
+                $this->io->setAuthentication($originUrl, $password, $username);
+            } else {
+                $this->io->setAuthentication($originUrl, $username, $password);
+            }
 
             return true;
         }
@@ -112,7 +119,7 @@ class GitLab
      *
      * @return bool true on success
      */
-    public function authorizeOAuthInteractively($scheme, $originUrl, $message = null)
+    public function authorizeOAuthInteractively(string $scheme, string $originUrl, string $message = null): bool
     {
         if ($message) {
             $this->io->writeError($message);
@@ -169,7 +176,7 @@ class GitLab
      *
      * @see https://docs.gitlab.com/ee/api/oauth2.html#resource-owner-password-credentials-flow
      */
-    private function createToken($scheme, $originUrl)
+    private function createToken(string $scheme, string $originUrl): array
     {
         $username = $this->io->ask('Username: ');
         $password = $this->io->askAndHideAnswer('Password: ');
