@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,6 +17,7 @@ use Composer\Downloader\MaxFileSizeExceededException;
 use Composer\IO\IOInterface;
 use Composer\Downloader\TransportException;
 use Composer\Pcre\Preg;
+use Composer\Util\Platform;
 use Composer\Util\StreamContextFactory;
 use Composer\Util\AuthHelper;
 use Composer\Util\Url;
@@ -27,8 +28,8 @@ use React\Promise\Promise;
  * @internal
  * @author Jordi Boggiano <j.boggiano@seld.be>
  * @author Nicolas Grekas <p@tchwork.com>
- * @phpstan-type Attributes array{retryAuthFailure: bool, redirects: int, retries: int, storeAuth: bool}
- * @phpstan-type Job array{url: string, origin: string, attributes: Attributes, options: mixed[], progress: mixed[], curlHandle: resource, filename: string|false, headerHandle: resource, bodyHandle: resource, resolve: callable, reject: callable}
+ * @phpstan-type Attributes array{retryAuthFailure: bool, redirects: int<0, max>, retries: int<0, max>, storeAuth: 'prompt'|bool}
+ * @phpstan-type Job array{url: string, origin: string, attributes: Attributes, options: mixed[], progress: mixed[], curlHandle: resource, filename: string|null, headerHandle: resource, bodyHandle: resource, resolve: callable, reject: callable}
  */
 class CurlDownloader
 {
@@ -95,7 +96,7 @@ class CurlDownloader
      * @param mixed[] $options
      * @param bool    $disableTls
      */
-    public function __construct(IOInterface $io, Config $config, array $options = array(), $disableTls = false)
+    public function __construct(IOInterface $io, Config $config, array $options = array(), bool $disableTls = false)
     {
         $this->io = $io;
         $this->config = $config;
@@ -129,11 +130,11 @@ class CurlDownloader
      * @param string   $origin
      * @param string   $url
      * @param mixed[]  $options
-     * @param ?string  $copyTo
+     * @param null|string  $copyTo
      *
      * @return int internal job id
      */
-    public function download($resolve, $reject, $origin, $url, $options, $copyTo = null)
+    public function download(callable $resolve, callable $reject, string $origin, string $url, array $options, ?string $copyTo = null): int
     {
         $attributes = array();
         if (isset($options['retry-auth-failure'])) {
@@ -150,26 +151,25 @@ class CurlDownloader
      * @param string   $origin
      * @param string   $url
      * @param mixed[]  $options
-     * @param ?string  $copyTo
+     * @param null|string  $copyTo
      *
-     * @param array{retryAuthFailure?: bool, redirects?: int, retries?: int, storeAuth?: bool} $attributes
+     * @param array{retryAuthFailure?: bool, redirects?: int<0, max>, retries?: int<0, max>, storeAuth?: 'prompt'|bool} $attributes
      *
      * @return int internal job id
      */
-    private function initDownload($resolve, $reject, $origin, $url, $options, $copyTo = null, array $attributes = array())
+    private function initDownload(callable $resolve, callable $reject, string $origin, string $url, array $options, ?string $copyTo = null, array $attributes = array()): int
     {
-        $attributes = array_merge(array(
-            'retryAuthFailure' => true,
-            'redirects' => 0,
-            'retries' => 0,
-            'storeAuth' => false,
-        ), $attributes);
+        // set defaults in a PHPStan-happy way (array_merge is not well supported)
+        $attributes['retryAuthFailure'] = $attributes['retryAuthFailure'] ?? true;
+        $attributes['redirects'] = $attributes['redirects'] ?? 0;
+        $attributes['retries'] = $attributes['retries'] ?? 0;
+        $attributes['storeAuth'] = $attributes['storeAuth'] ?? false;
 
         $originalOptions = $options;
 
         // check URL can be accessed (i.e. is not insecure), but allow insecure Packagist calls to $hashed providers as file integrity is verified with sha256
         if (!Preg::isMatch('{^http://(repo\.)?packagist\.org/p/}', $url) || (false === strpos($url, '$') && false === strpos($url, '%24'))) {
-            $this->config->prohibitUrlByConfig($url, $this->io);
+            $this->config->prohibitUrlByConfig($url, $this->io, $options);
         }
 
         $curlHandle = curl_init();
@@ -178,10 +178,11 @@ class CurlDownloader
             throw new \RuntimeException('Failed to open a temp stream to store curl headers');
         }
 
+
         if ($copyTo) {
             $errorMessage = '';
             // @phpstan-ignore-next-line
-            set_error_handler(function ($code, $msg) use (&$errorMessage) {
+            set_error_handler(function ($code, $msg) use (&$errorMessage): void {
                 if ($errorMessage) {
                     $errorMessage .= "\n";
                 }
@@ -288,7 +289,7 @@ class CurlDownloader
      * @param  int  $id
      * @return void
      */
-    public function abortRequest($id)
+    public function abortRequest(int $id): void
     {
         if (isset($this->jobs[$id], $this->jobs[$id]['curlHandle'])) {
             $job = $this->jobs[$id];
@@ -300,7 +301,7 @@ class CurlDownloader
             if (is_resource($job['bodyHandle'])) {
                 fclose($job['bodyHandle']);
             }
-            if ($job['filename']) {
+            if (null !== $job['filename']) {
                 @unlink($job['filename'].'~');
             }
             unset($this->jobs[$id]);
@@ -310,11 +311,11 @@ class CurlDownloader
     /**
      * @return void
      */
-    public function tick()
+    public function tick(): void
     {
         static $timeoutWarning = false;
 
-        if (!$this->jobs) {
+        if (count($this->jobs) === 0) {
             return;
         }
 
@@ -334,6 +335,9 @@ class CurlDownloader
             }
 
             $progress = curl_getinfo($curlHandle);
+            if (false === $progress) {
+                throw new \RuntimeException('Failed getting info from curl handle '.$i.' ('.$this->jobs[$i]['url'].')');
+            }
             $job = $this->jobs[$i];
             unset($this->jobs[$i]);
             $error = curl_error($curlHandle);
@@ -356,16 +360,16 @@ class CurlDownloader
                     if (
                         (!isset($job['options']['http']['method']) || $job['options']['http']['method'] === 'GET')
                         && (
-                            in_array($errno, array(7 /* CURLE_COULDNT_CONNECT */, 16 /* CURLE_HTTP2 */, 92 /* CURLE_HTTP2_STREAM */), true)
+                            in_array($errno, array(7 /* CURLE_COULDNT_CONNECT */, 16 /* CURLE_HTTP2 */, 92 /* CURLE_HTTP2_STREAM */, 6 /* CURLE_COULDNT_RESOLVE_HOST */), true)
                             || ($errno === 35 /* CURLE_SSL_CONNECT_ERROR */ && false !== strpos($error, 'Connection reset by peer'))
                         ) && $job['attributes']['retries'] < $this->maxRetries
                     ) {
                         $this->io->writeError('Retrying ('.($job['attributes']['retries'] + 1).') ' . Url::sanitize($job['url']) . ' due to curl error '. $errno, true, IOInterface::DEBUG);
-                        $this->restartJob($job, $job['url'], array('retries' => $job['attributes']['retries'] + 1));
+                        $this->restartJobWithDelay($job, $job['url'], array('retries' => $job['attributes']['retries'] + 1));
                         continue;
                     }
 
-                    if ($errno === 28 /* CURLE_OPERATION_TIMEDOUT */ && isset($progress['namelookup_time']) && $progress['namelookup_time'] == 0 && !$timeoutWarning) {
+                    if ($errno === 28 /* CURLE_OPERATION_TIMEDOUT */ && PHP_VERSION_ID >= 70300 && $progress['namelookup_time'] == 0 && !$timeoutWarning) {
                         $timeoutWarning = true;
                         $this->io->writeError('<warning>A connection timeout was encountered. If you intend to run Composer without connecting to the internet, run the command again prefixed with COMPOSER_DISABLE_NETWORK=1 to make Composer run in offline mode.</warning>');
                     }
@@ -382,7 +386,7 @@ class CurlDownloader
                 }
 
                 // prepare response object
-                if ($job['filename']) {
+                if (null !== $job['filename']) {
                     $contents = $job['filename'].'~';
                     if ($statusCode >= 300) {
                         rewind($job['bodyHandle']);
@@ -391,8 +395,19 @@ class CurlDownloader
                     $response = new CurlResponse(array('url' => $progress['url']), $statusCode, $headers, $contents, $progress);
                     $this->io->writeError('['.$statusCode.'] '.Url::sanitize($progress['url']), true, IOInterface::DEBUG);
                 } else {
+                    $maxFileSize = $job['options']['max_file_size'] ?? null;
                     rewind($job['bodyHandle']);
-                    $contents = stream_get_contents($job['bodyHandle']);
+                    if ($maxFileSize !== null) {
+                        $contents = stream_get_contents($job['bodyHandle'], $maxFileSize);
+                        // Gzipped responses with missing Content-Length header cannot be detected during the file download
+                        // because $progress['size_download'] refers to the gzipped size downloaded, not the actual file size
+                        if ($contents !== false && Platform::strlen($contents) >= $maxFileSize) {
+                            throw new MaxFileSizeExceededException('Maximum allowed download size reached. Downloaded ' . Platform::strlen($contents) . ' of allowed ' .  $maxFileSize . ' bytes');
+                        }
+                    } else {
+                        $contents = stream_get_contents($job['bodyHandle']);
+                    }
+
                     $response = new CurlResponse(array('url' => $progress['url']), $statusCode, $headers, $contents, $progress);
                     $this->io->writeError('['.$statusCode.'] '.Url::sanitize($progress['url']), true, IOInterface::DEBUG);
                 }
@@ -425,33 +440,33 @@ class CurlDownloader
                         && $job['attributes']['retries'] < $this->maxRetries
                     ) {
                         $this->io->writeError('Retrying ('.($job['attributes']['retries'] + 1).') ' . Url::sanitize($job['url']) . ' due to status code '. $statusCode, true, IOInterface::DEBUG);
-                        $this->restartJob($job, $job['url'], array('retries' => $job['attributes']['retries'] + 1));
+                        $this->restartJobWithDelay($job, $job['url'], array('retries' => $job['attributes']['retries'] + 1));
                         continue;
                     }
 
                     throw $this->failResponse($job, $response, $response->getStatusMessage());
                 }
 
-                if ($job['attributes']['storeAuth']) {
+                if ($job['attributes']['storeAuth'] !== false) {
                     $this->authHelper->storeAuth($job['origin'], $job['attributes']['storeAuth']);
                 }
 
                 // resolve promise
-                if ($job['filename']) {
+                if (null !== $job['filename']) {
                     rename($job['filename'].'~', $job['filename']);
                     call_user_func($job['resolve'], $response);
                 } else {
                     call_user_func($job['resolve'], $response);
                 }
             } catch (\Exception $e) {
-                if ($e instanceof TransportException && $headers) {
-                    $e->setHeaders($headers);
-                    $e->setStatusCode($statusCode);
-                }
-                if ($e instanceof TransportException && $response) {
-                    $e->setResponse($response->getBody());
-                }
-                if ($e instanceof TransportException && $progress) {
+                if ($e instanceof TransportException) {
+                    if (null !== $headers) {
+                        $e->setHeaders($headers);
+                        $e->setStatusCode($statusCode);
+                    }
+                    if (null !== $response) {
+                        $e->setResponse($response->getBody());
+                    }
                     $e->setResponseInfo($progress);
                 }
 
@@ -490,7 +505,7 @@ class CurlDownloader
      * @param  Job    $job
      * @return string
      */
-    private function handleRedirect(array $job, Response $response)
+    private function handleRedirect(array $job, Response $response): string
     {
         if ($locationHeader = $response->getHeader('location')) {
             if (parse_url($locationHeader, PHP_URL_SCHEME)) {
@@ -522,13 +537,13 @@ class CurlDownloader
     }
 
     /**
-     * @param  Job                                        $job
-     * @return array{retry: bool, storeAuth: string|bool}
+     * @param  Job                                          $job
+     * @return array{retry: bool, storeAuth: 'prompt'|bool}
      */
-    private function isAuthenticatedRetryNeeded(array $job, Response $response)
+    private function isAuthenticatedRetryNeeded(array $job, Response $response): array
     {
         if (in_array($response->getStatusCode(), array(401, 403)) && $job['attributes']['retryAuthFailure']) {
-            $result = $this->authHelper->promptAuthIfNeeded($job['url'], $job['origin'], $response->getStatusCode(), $response->getStatusMessage(), $response->getHeaders());
+            $result = $this->authHelper->promptAuthIfNeeded($job['url'], $job['origin'], $response->getStatusCode(), $response->getStatusMessage(), $response->getHeaders(), $job['attributes']['retries']);
 
             if ($result['retry']) {
                 return $result;
@@ -560,7 +575,7 @@ class CurlDownloader
 
         if ($needsAuthRetry) {
             if ($job['attributes']['retryAuthFailure']) {
-                $result = $this->authHelper->promptAuthIfNeeded($job['url'], $job['origin'], 401);
+                $result = $this->authHelper->promptAuthIfNeeded($job['url'], $job['origin'], 401, null, array(), $job['attributes']['retries']);
                 if ($result['retry']) {
                     return $result;
                 }
@@ -576,13 +591,13 @@ class CurlDownloader
      * @param  Job    $job
      * @param  string $url
      *
-     * @param  array{retryAuthFailure?: bool, redirects?: int, storeAuth?: bool} $attributes
+     * @param  array{retryAuthFailure?: bool, redirects?: int<0, max>, storeAuth?: 'prompt'|bool, retries?: int<1, max>} $attributes
      *
      * @return void
      */
-    private function restartJob(array $job, $url, array $attributes = array())
+    private function restartJob(array $job, string $url, array $attributes = array()): void
     {
-        if ($job['filename']) {
+        if (null !== $job['filename']) {
             @unlink($job['filename'].'~');
         }
 
@@ -592,19 +607,38 @@ class CurlDownloader
         $this->initDownload($job['resolve'], $job['reject'], $origin, $url, $job['options'], $job['filename'], $attributes);
     }
 
+    /**
+     * @param  Job    $job
+     * @param  string $url
+     *
+     * @param  array{retryAuthFailure?: bool, redirects?: int<0, max>, storeAuth?: 'prompt'|bool, retries: int<1, max>} $attributes
+     *
+     * @return void
+     */
+    private function restartJobWithDelay(array $job, string $url, array $attributes): void
+    {
+        if ($attributes['retries'] >= 3) {
+            usleep(500000); // half a second delay for 3rd retry and beyond
+        } elseif ($attributes['retries'] >= 2) {
+            usleep(100000); // 100ms delay for 2nd retry
+        } // no sleep for the first retry
+
+        $this->restartJob($job, $url, $attributes);
+    }
+
     /**
      * @param  Job                $job
      * @param  string             $errorMessage
      * @return TransportException
      */
-    private function failResponse(array $job, Response $response, $errorMessage)
+    private function failResponse(array $job, Response $response, string $errorMessage): TransportException
     {
-        if ($job['filename']) {
+        if (null !== $job['filename']) {
             @unlink($job['filename'].'~');
         }
 
         $details = '';
-        if (in_array(strtolower($response->getHeader('content-type')), array('application/json', 'application/json; charset=utf-8'), true)) {
+        if (in_array(strtolower((string) $response->getHeader('content-type')), array('application/json', 'application/json; charset=utf-8'), true)) {
             $details = ':'.PHP_EOL.substr($response->getBody(), 0, 200).(strlen($response->getBody()) > 200 ? '...' : '');
         }
 
@@ -615,7 +649,7 @@ class CurlDownloader
      * @param  Job                $job
      * @return void
      */
-    private function rejectJob(array $job, \Exception $e)
+    private function rejectJob(array $job, \Exception $e): void
     {
         if (is_resource($job['headerHandle'])) {
             fclose($job['headerHandle']);
@@ -623,7 +657,7 @@ class CurlDownloader
         if (is_resource($job['bodyHandle'])) {
             fclose($job['bodyHandle']);
         }
-        if ($job['filename']) {
+        if (null !== $job['filename']) {
             @unlink($job['filename'].'~');
         }
         call_user_func($job['reject'], $e);
@@ -633,7 +667,7 @@ class CurlDownloader
      * @param  int  $code
      * @return void
      */
-    private function checkCurlResult($code)
+    private function checkCurlResult(int $code): void
     {
         if ($code != CURLM_OK && $code != CURLM_CALL_MULTI_PERFORM) {
             throw new \RuntimeException(
