@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -30,7 +30,7 @@ use Composer\Installer\InstallationManager;
 use Composer\Config;
 use Composer\EventDispatcher\EventDispatcher;
 use Composer\Util\Platform;
-use PHPUnit_Framework_MockObject_MockObject as MockObject;
+use PHPUnit\Framework\MockObject\MockObject;
 
 class AutoloadGeneratorTest extends TestCase
 {
@@ -55,12 +55,12 @@ class AutoloadGeneratorTest extends TestCase
     private $origDir;
 
     /**
-     * @var InstallationManager|MockObject
+     * @var InstallationManager&MockObject
      */
     private $im;
 
     /**
-     * @var InstalledRepositoryInterface|MockObject
+     * @var InstalledRepositoryInterface&MockObject
      */
     private $repository;
 
@@ -75,7 +75,7 @@ class AutoloadGeneratorTest extends TestCase
     private $fs;
 
     /**
-     * @var EventDispatcher|MockObject
+     * @var EventDispatcher&MockObject
      */
     private $eventDispatcher;
 
@@ -83,39 +83,38 @@ class AutoloadGeneratorTest extends TestCase
      * Map of setting name => return value configuration for the stub Config
      * object.
      *
-     * Note: must be public for compatibility with PHP 5.3 runtimes where
-     * closures cannot access private members of the classes they are created
-     * in.
      * @var array<string, callable|boolean>
      */
-    public $configValueMap;
+    private $configValueMap;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->fs = new Filesystem;
-        $that = $this;
 
-        $this->workingDir = $this->getUniqueTmpDirectory();
+        $this->workingDir = self::getUniqueTmpDirectory();
         $this->vendorDir = $this->workingDir.DIRECTORY_SEPARATOR.'composer-test-autoload';
         $this->ensureDirectoryExistsAndClear($this->vendorDir);
 
         $this->config = $this->getMockBuilder('Composer\Config')->getMock();
 
         $this->configValueMap = array(
-            'vendor-dir' => function () use ($that) {
-                return $that->vendorDir;
+            'vendor-dir' => function (): string {
+                return $this->vendorDir;
             },
-            'platform-check' => function () {
+            'platform-check' => function (): bool {
                 return true;
             },
+            'use-include-path' => function (): bool {
+                return false;
+            },
         );
 
         $this->config->expects($this->atLeastOnce())
             ->method('get')
-            ->will($this->returnCallback(function ($arg) use ($that) {
+            ->will($this->returnCallback(function ($arg) {
                 $ret = null;
-                if (isset($that->configValueMap[$arg])) {
-                    $ret = $that->configValueMap[$arg];
+                if (isset($this->configValueMap[$arg])) {
+                    $ret = $this->configValueMap[$arg];
                     if (is_callable($ret)) {
                         $ret = $ret();
                     }
@@ -124,7 +123,7 @@ class AutoloadGeneratorTest extends TestCase
                 return $ret;
             }));
 
-        $this->origDir = getcwd();
+        $this->origDir = Platform::getCwd();
         chdir($this->workingDir);
 
         $this->im = $this->getMockBuilder('Composer\Installer\InstallationManager')
@@ -132,10 +131,10 @@ class AutoloadGeneratorTest extends TestCase
             ->getMock();
         $this->im->expects($this->any())
             ->method('getInstallPath')
-            ->will($this->returnCallback(function ($package) use ($that) {
+            ->will($this->returnCallback(function ($package): string {
                 $targetDir = $package->getTargetDir();
 
-                return $that->vendorDir.'/'.$package->getName() . ($targetDir ? '/'.$targetDir : '');
+                return $this->vendorDir.'/'.$package->getName() . ($targetDir ? '/'.$targetDir : '');
             }));
         $this->repository = $this->getMockBuilder('Composer\Repository\InstalledRepositoryInterface')->getMock();
         $this->repository->expects($this->any())
@@ -149,8 +148,9 @@ class AutoloadGeneratorTest extends TestCase
         $this->generator = new AutoloadGenerator($this->eventDispatcher);
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         chdir($this->origDir);
 
         if (is_dir($this->workingDir)) {
@@ -162,7 +162,7 @@ class AutoloadGeneratorTest extends TestCase
         }
     }
 
-    public function testRootPackageAutoloading()
+    public function testRootPackageAutoloading(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -207,7 +207,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('classmap', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testRootPackageDevAutoloading()
+    public function testRootPackageDevAutoloading(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -245,7 +245,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('files2', $this->vendorDir.'/composer', 'files');
     }
 
-    public function testRootPackageDevAutoloadingDisabledByDefault()
+    public function testRootPackageDevAutoloadingDisabledByDefault(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -278,7 +278,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertFalse(is_file($this->vendorDir.'/composer/autoload_files.php'));
     }
 
-    public function testVendorDirSameAsWorkingDir()
+    public function testVendorDirSameAsWorkingDir(): void
     {
         $this->vendorDir = $this->workingDir;
 
@@ -309,7 +309,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('classmap3', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testRootPackageAutoloadingAlternativeVendorDir()
+    public function testRootPackageAutoloadingAlternativeVendorDir(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -338,7 +338,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('classmap2', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testRootPackageAutoloadingWithTargetDir()
+    public function testRootPackageAutoloadingWithTargetDir(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -369,7 +369,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('classmap6', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testVendorsAutoloading()
+    public function testVendorsAutoloading(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -398,7 +398,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertFileExists($this->vendorDir.'/composer/autoload_classmap.php', "ClassMap file needs to be generated, even if empty.");
     }
 
-    public function testNonDevAutoloadExclusionWithRecursion()
+    public function testNonDevAutoloadExclusionWithRecursion(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -431,7 +431,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertFileExists($this->vendorDir.'/composer/autoload_classmap.php', "ClassMap file needs to be generated, even if empty.");
     }
 
-    public function testNonDevAutoloadShouldIncludeReplacedPackages()
+    public function testNonDevAutoloadShouldIncludeReplacedPackages(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array('a/a' => new Link('a', 'a/a', new MatchAllConstraint())));
@@ -465,7 +465,7 @@ class AutoloadGeneratorTest extends TestCase
         );
     }
 
-    public function testNonDevAutoloadExclusionWithRecursionReplace()
+    public function testNonDevAutoloadExclusionWithRecursionReplace(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -498,7 +498,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertFileExists($this->vendorDir.'/composer/autoload_classmap.php', "ClassMap file needs to be generated, even if empty.");
     }
 
-    public function testNonDevAutoloadReplacesNestedRequirements()
+    public function testNonDevAutoloadReplacesNestedRequirements(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -550,7 +550,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('classmap9', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testPharAutoload()
+    public function testPharAutoload(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -591,7 +591,7 @@ class AutoloadGeneratorTest extends TestCase
         $this->assertAutoloadFiles('phar_static', $this->vendorDir . '/composer', 'static');
     }
 
-    public function testPSRToClassMapIgnoresNonExistingDir()
+    public function testPSRToClassMapIgnoresNonExistingDir(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
 
@@ -614,7 +614,7 @@ class AutoloadGeneratorTest extends TestCase
         );
     }
 
-    public function testPSRToClassMapIgnoresNonPSRClasses()
+    public function testPSRToClassMapIgnoresNonPSRClasses(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
 
@@ -642,7 +642,7 @@ class AutoloadGeneratorTest extends TestCase
 
 // autoload_classmap.php @generated by Composer
 
-\$vendorDir = dirname(dirname(__FILE__));
+\$vendorDir = dirname(__DIR__);
 \$baseDir = dirname(\$vendorDir);
 
 return array(
@@ -655,7 +655,7 @@ EOF;
         $this->assertStringEqualsFile($this->vendorDir.'/composer/autoload_classmap.php', $expectedClassmap);
     }
 
-    public function testVendorsClassMapAutoloading()
+    public function testVendorsClassMapAutoloading(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -695,7 +695,7 @@ EOF;
         $this->assertAutoloadFiles('classmap4', $this->vendorDir.'/composer', 'classmap');
     }
 
-    public function testVendorsClassMapAutoloadingWithTargetDir()
+    public function testVendorsClassMapAutoloadingWithTargetDir(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -735,7 +735,7 @@ EOF;
         );
     }
 
-    public function testClassMapAutoloadingEmptyDirAndExactFile()
+    public function testClassMapAutoloadingEmptyDirAndExactFile(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -780,7 +780,7 @@ EOF;
         $this->assertStringNotContainsString('$loader->setApcuPrefix(', (string) file_get_contents($this->vendorDir.'/composer/autoload_real.php'));
     }
 
-    public function testClassMapAutoloadingAuthoritativeAndApcu()
+    public function testClassMapAutoloadingAuthoritativeAndApcu(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -829,7 +829,7 @@ EOF;
         $this->assertStringContainsString('$loader->setApcuPrefix(', (string) file_get_contents($this->vendorDir.'/composer/autoload_real.php'));
     }
 
-    public function testClassMapAutoloadingAuthoritativeAndApcuPrefix()
+    public function testClassMapAutoloadingAuthoritativeAndApcuPrefix(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -878,7 +878,7 @@ EOF;
         $this->assertStringContainsString('$loader->setApcuPrefix(\'custom\\\'Prefix\');', (string) file_get_contents($this->vendorDir.'/composer/autoload_real.php'));
     }
 
-    public function testFilesAutoloadGeneration()
+    public function testFilesAutoloadGeneration(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array('files' => array('root.php')));
@@ -925,7 +925,7 @@ EOF;
         $this->assertTrue(function_exists('testFilesAutoloadGenerationRoot'));
     }
 
-    public function testFilesAutoloadGenerationRemoveExtraEntitiesFromAutoloadFiles()
+    public function testFilesAutoloadGenerationRemoveExtraEntitiesFromAutoloadFiles(): void
     {
         $autoloadPackage = new RootPackage('root/a', '1.0', '1.0');
         $autoloadPackage->setAutoload(array('files' => array('root.php')));
@@ -958,17 +958,13 @@ EOF;
         $notAutoloadPackages[] = $b = new Package('b/b', '1.0', '1.0');
         $notAutoloadPackages[] = $c = new Package('c/c', '1.0', '1.0');
 
-        $this->repository->expects($this->at(1))
+        $this->repository->expects($this->exactly(3))
             ->method('getCanonicalPackages')
-            ->will($this->returnValue($autoloadPackages));
-
-        $this->repository->expects($this->at(3))
-            ->method('getCanonicalPackages')
-            ->will($this->returnValue($notAutoloadPackages));
-
-        $this->repository->expects($this->at(5))
-            ->method('getCanonicalPackages')
-            ->will($this->returnValue($notAutoloadPackages));
+            ->willReturnOnConsecutiveCalls(
+                $autoloadPackages,
+                $notAutoloadPackages,
+                $notAutoloadPackages
+            );
 
         $this->fs->ensureDirectoryExists($this->vendorDir.'/a/a');
         $this->fs->ensureDirectoryExists($this->vendorDir.'/b/b');
@@ -1000,7 +996,7 @@ EOF;
         $this->assertFileDoesNotExist($this->vendorDir.'/composer/include_paths.php');
     }
 
-    public function testFilesAutoloadOrderByDependencies()
+    public function testFilesAutoloadOrderByDependencies(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array('files' => array('root2.php')));
@@ -1078,7 +1074,7 @@ EOF;
      * - The main package has priority over other packages.
      * - Longer namespaces have priority over shorter namespaces.
      */
-    public function testOverrideVendorsAutoloading()
+    public function testOverrideVendorsAutoloading(): void
     {
         $rootPackage = new RootPackage('root/z', '1.0', '1.0');
         $rootPackage->setAutoload(array(
@@ -1126,7 +1122,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-\$vendorDir = dirname(dirname(__FILE__));
+\$vendorDir = dirname(__DIR__);
 \$baseDir = dirname(\$vendorDir);
 
 return array(
@@ -1143,7 +1139,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-\$vendorDir = dirname(dirname(__FILE__));
+\$vendorDir = dirname(__DIR__);
 \$baseDir = dirname(\$vendorDir);
 
 return array(
@@ -1156,7 +1152,7 @@ EOF;
 
 // autoload_classmap.php @generated by Composer
 
-\$vendorDir = dirname(dirname(__FILE__));
+\$vendorDir = dirname(__DIR__);
 \$baseDir = dirname(\$vendorDir);
 
 return array(
@@ -1173,7 +1169,7 @@ EOF;
         $this->assertStringEqualsFile($this->vendorDir.'/composer/autoload_classmap.php', $expectedClassmap);
     }
 
-    public function testIncludePathFileGeneration()
+    public function testIncludePathFileGeneration(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $packages = array();
@@ -1210,7 +1206,7 @@ EOF;
         );
     }
 
-    public function testIncludePathsArePrependedInAutoloadFile()
+    public function testIncludePathsArePrependedInAutoloadFile(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $packages = array();
@@ -1241,7 +1237,7 @@ EOF;
         set_include_path($oldIncludePath);
     }
 
-    public function testIncludePathsInRootPackage()
+    public function testIncludePathsInRootPackage(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setIncludePaths(array('/lib', '/src'));
@@ -1270,7 +1266,7 @@ EOF;
         set_include_path($oldIncludePath);
     }
 
-    public function testIncludePathFileWithoutPathsIsSkipped()
+    public function testIncludePathFileWithoutPathsIsSkipped(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $packages = array();
@@ -1289,17 +1285,15 @@ EOF;
         $this->assertFileDoesNotExist($this->vendorDir."/composer/include_paths.php");
     }
 
-    public function testPreAndPostEventsAreDispatchedDuringAutoloadDump()
+    public function testPreAndPostEventsAreDispatchedDuringAutoloadDump(): void
     {
         $this->eventDispatcher
-            ->expects($this->at(0))
+            ->expects($this->exactly(2))
             ->method('dispatchScript')
-            ->with(ScriptEvents::PRE_AUTOLOAD_DUMP, false);
-
-        $this->eventDispatcher
-            ->expects($this->at(1))
-            ->method('dispatchScript')
-            ->with(ScriptEvents::POST_AUTOLOAD_DUMP, false);
+            ->withConsecutive(
+                [ScriptEvents::PRE_AUTOLOAD_DUMP, false],
+                [ScriptEvents::POST_AUTOLOAD_DUMP, false]
+            );
 
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array('psr-0' => array('Prefix' => 'foo/bar/non/existing/')));
@@ -1312,7 +1306,7 @@ EOF;
         $this->generator->dump($this->config, $this->repository, $package, $this->im, 'composer', true, '_8');
     }
 
-    public function testUseGlobalIncludePath()
+    public function testUseGlobalIncludePath(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -1333,7 +1327,7 @@ EOF;
         $this->assertFileContentEquals(__DIR__.'/Fixtures/autoload_static_include_path.php', $this->vendorDir.'/composer/autoload_static.php');
     }
 
-    public function testVendorDirExcludedFromWorkingDir()
+    public function testVendorDirExcludedFromWorkingDir(): void
     {
         $workingDir = $this->vendorDir.'/working-dir';
         $vendorDir = $workingDir.'/../vendor';
@@ -1369,7 +1363,7 @@ EOF;
             ->getMock();
         $im->expects($this->any())
             ->method('getInstallPath')
-            ->will($this->returnCallback(function ($package) use ($vendorDir) {
+            ->will($this->returnCallback(function ($package) use ($vendorDir): string {
                 $targetDir = $package->getTargetDir();
 
                 return $vendorDir.'/'.$package->getName() . ($targetDir ? '/'.$targetDir : '');
@@ -1397,7 +1391,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1412,7 +1406,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1427,7 +1421,7 @@ EOF;
 
 // autoload_classmap.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1447,7 +1441,7 @@ EOF;
         $this->assertStringContainsString("\$baseDir . '/test.php',\n", (string) file_get_contents($vendorDir.'/composer/autoload_files.php'));
     }
 
-    public function testUpLevelRelativePaths()
+    public function testUpLevelRelativePaths(): void
     {
         $workingDir = $this->workingDir.'/working-dir';
         mkdir($workingDir, 0777, true);
@@ -1486,7 +1480,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1500,7 +1494,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1514,7 +1508,7 @@ EOF;
 
 // autoload_classmap.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir).'/working-dir';
 
 return array(
@@ -1531,7 +1525,7 @@ EOF;
         $this->assertStringContainsString("\$baseDir . '/../test.php',\n", (string) file_get_contents($this->vendorDir.'/composer/autoload_files.php'));
     }
 
-    public function testAutoloadRulesInPackageThatDoesNotExistOnDisk()
+    public function testAutoloadRulesInPackageThatDoesNotExistOnDisk(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires(array(
@@ -1553,7 +1547,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1573,7 +1567,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1612,7 +1606,7 @@ EOF;
         ), $parsed['exclude-from-classmap']);
     }
 
-    public function testEmptyPaths()
+    public function testEmptyPaths(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -1636,7 +1630,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1650,7 +1644,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1664,7 +1658,7 @@ EOF;
 
 // autoload_classmap.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1680,7 +1674,7 @@ EOF;
         $this->assertStringEqualsFile($this->vendorDir.'/composer/autoload_classmap.php', $expectedClassmap);
     }
 
-    public function testVendorSubstringPath()
+    public function testVendorSubstringPath(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -1699,7 +1693,7 @@ EOF;
 
 // autoload_namespaces.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1713,7 +1707,7 @@ EOF;
 
 // autoload_psr4.php @generated by Composer
 
-$vendorDir = dirname(dirname(__FILE__));
+$vendorDir = dirname(__DIR__);
 $baseDir = dirname($vendorDir);
 
 return array(
@@ -1727,7 +1721,7 @@ EOF;
         $this->assertStringEqualsFile($this->vendorDir.'/composer/autoload_psr4.php', $expectedPsr4);
     }
 
-    public function testExcludeFromClassmap()
+    public function testExcludeFromClassmap(): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setAutoload(array(
@@ -1801,11 +1795,11 @@ EOF;
      * @param string|null          $expectedFixture
      * @param array<string, Link>  $provides
      * @param array<string, Link>  $replaces
-     * @param bool                 $ignorePlatformReqs
+     * @param bool|array<string>   $ignorePlatformReqs
      *
      * @dataProvider platformCheckProvider
      */
-    public function testGeneratesPlatformCheck(array $requires, $expectedFixture, array $provides = array(), array $replaces = array(), $ignorePlatformReqs = false)
+    public function testGeneratesPlatformCheck(array $requires, ?string $expectedFixture, array $provides = array(), array $replaces = array(), $ignorePlatformReqs = false): void
     {
         $package = new RootPackage('root/a', '1.0', '1.0');
         $package->setRequires($requires);
@@ -1837,7 +1831,7 @@ EOF;
     /**
      * @return array<string, mixed[]>
      */
-    public function platformCheckProvider()
+    public function platformCheckProvider(): array
     {
         $versionParser = new VersionParser();
 
@@ -1946,7 +1940,7 @@ EOF;
      *
      * @return void
      */
-    private function assertAutoloadFiles($name, $dir, $type = 'namespaces')
+    private function assertAutoloadFiles(string $name, string $dir, string $type = 'namespaces'): void
     {
         $a = __DIR__.'/Fixtures/autoload_'.$name.'.php';
         $b = $dir.'/autoload_'.$type.'.php';
@@ -1956,38 +1950,16 @@ EOF;
     /**
      * @param string $expected
      * @param string $actual
-     * @param string $message
-     * @param bool   $canonicalize
-     * @param bool   $ignoreCase
+     * @param string|null $message
      *
      * @return void
      */
-    public static function assertFileContentEquals($expected, $actual, $message = '', $canonicalize = false, $ignoreCase = false)
+    public static function assertFileContentEquals(string $expected, string $actual, ?string $message = null): void
     {
-        self::assertEqualsNormalized(
-            (string) file_get_contents($expected),
-            (string) file_get_contents($actual),
-            $message ?: $expected.' equals '.$actual,
-            0,
-            10,
-            $canonicalize,
-            $ignoreCase
+        self::assertSame(
+            str_replace("\r", '', (string) file_get_contents($expected)),
+            str_replace("\r", '', (string) file_get_contents($actual)),
+            $message ?? $expected.' equals '.$actual
         );
     }
-
-    /**
-     * @param string $expected
-     * @param string $actual
-     * @param string $message
-     * @param int    $delta
-     * @param int    $maxDepth
-     * @param bool   $canonicalize
-     * @param bool   $ignoreCase
-     *
-     * @return void
-     */
-    public static function assertEqualsNormalized($expected, $actual, $message = '', $delta = 0, $maxDepth = 10, $canonicalize = false, $ignoreCase = false)
-    {
-        parent::assertEquals(str_replace("\r", '', $expected), str_replace("\r", '', $actual), $message, $delta, $maxDepth, $canonicalize, $ignoreCase);
-    }
 }
