@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -19,7 +19,7 @@ class ArchiveDownloaderTest extends TestCase
     /** @var \Composer\Config&\PHPUnit\Framework\MockObject\MockObject */
     protected $config;
 
-    public function testGetFileName()
+    public function testGetFileName(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -41,7 +41,7 @@ class ArchiveDownloaderTest extends TestCase
         $this->assertSame($first, $method->invoke($downloader, $packageMock, '/path'));
     }
 
-    public function testProcessUrl()
+    public function testProcessUrl(): void
     {
         if (!extension_loaded('openssl')) {
             $this->markTestSkipped('Requires openssl');
@@ -57,7 +57,7 @@ class ArchiveDownloaderTest extends TestCase
         $this->assertEquals($expected, $url);
     }
 
-    public function testProcessUrl2()
+    public function testProcessUrl2(): void
     {
         if (!extension_loaded('openssl')) {
             $this->markTestSkipped('Requires openssl');
@@ -73,7 +73,7 @@ class ArchiveDownloaderTest extends TestCase
         $this->assertEquals($expected, $url);
     }
 
-    public function testProcessUrl3()
+    public function testProcessUrl3(): void
     {
         if (!extension_loaded('openssl')) {
             $this->markTestSkipped('Requires openssl');
@@ -93,7 +93,7 @@ class ArchiveDownloaderTest extends TestCase
      * @dataProvider provideUrls
      * @param string $url
      */
-    public function testProcessUrlRewriteDist($url)
+    public function testProcessUrlRewriteDist(string $url): void
     {
         if (!extension_loaded('openssl')) {
             $this->markTestSkipped('Requires openssl');
@@ -115,7 +115,7 @@ class ArchiveDownloaderTest extends TestCase
         $this->assertEquals($expected, $url);
     }
 
-    public function provideUrls()
+    public function provideUrls(): array
     {
         return array(
             array('https://api.github.com/repos/composer/composer/zipball/master'),
@@ -132,7 +132,7 @@ class ArchiveDownloaderTest extends TestCase
      * @param string $url
      * @param string $extension
      */
-    public function testProcessUrlRewriteBitbucketDist($url, $extension)
+    public function testProcessUrlRewriteBitbucketDist(string $url, string $extension): void
     {
         if (!extension_loaded('openssl')) {
             $this->markTestSkipped('Requires openssl');
@@ -154,7 +154,7 @@ class ArchiveDownloaderTest extends TestCase
         $this->assertEquals($expected, $url);
     }
 
-    public function provideBitbucketUrls()
+    public function provideBitbucketUrls(): array
     {
         return array(
             array('https://bitbucket.org/davereid/drush-virtualhost/get/77ca490c26ac818e024d1138aa8bd3677d1ef21f', 'zip'),
