@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,6 +13,7 @@
 namespace Composer\Test\Downloader;
 
 use Composer\Downloader\DownloadManager;
+use Composer\Package\PackageInterface;
 use Composer\Test\TestCase;
 
 class DownloadManagerTest extends TestCase
@@ -23,13 +24,13 @@ class DownloadManagerTest extends TestCase
     /** @var \Composer\IO\IOInterface&\PHPUnit\Framework\MockObject\MockObject */
     protected $io;
 
-    public function setUp()
+    public function setUp(): void
     {
         $this->filesystem = $this->getMockBuilder('Composer\Util\Filesystem')->getMock();
         $this->io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
     }
 
-    public function testSetGetDownloader()
+    public function testSetGetDownloader(): void
     {
         $downloader = $this->createDownloaderMock();
         $manager = new DownloadManager($this->io, false, $this->filesystem);
@@ -37,11 +38,11 @@ class DownloadManagerTest extends TestCase
         $manager->setDownloader('test', $downloader);
         $this->assertSame($downloader, $manager->getDownloader('test'));
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
         $manager->getDownloader('unregistered');
     }
 
-    public function testGetDownloaderForIncorrectlyInstalledPackage()
+    public function testGetDownloaderForIncorrectlyInstalledPackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -51,12 +52,12 @@ class DownloadManagerTest extends TestCase
 
         $manager = new DownloadManager($this->io, false, $this->filesystem);
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
 
         $manager->getDownloaderForPackage($package);
     }
 
-    public function testGetDownloaderForCorrectlyInstalledDistPackage()
+    public function testGetDownloaderForCorrectlyInstalledDistPackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -76,7 +77,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloader'))
+            ->onlyMethods(array('getDownloader'))
             ->getMock();
 
         $manager
@@ -88,7 +89,7 @@ class DownloadManagerTest extends TestCase
         $this->assertSame($downloader, $manager->getDownloaderForPackage($package));
     }
 
-    public function testGetDownloaderForIncorrectlyInstalledDistPackage()
+    public function testGetDownloaderForIncorrectlyInstalledDistPackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -108,7 +109,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloader'))
+            ->onlyMethods(array('getDownloader'))
             ->getMock();
 
         $manager
@@ -117,12 +118,12 @@ class DownloadManagerTest extends TestCase
             ->with('git')
             ->will($this->returnValue($downloader));
 
-        $this->setExpectedException('LogicException');
+        self::expectException('LogicException');
 
         $manager->getDownloaderForPackage($package);
     }
 
-    public function testGetDownloaderForCorrectlyInstalledSourcePackage()
+    public function testGetDownloaderForCorrectlyInstalledSourcePackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -142,7 +143,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloader'))
+            ->onlyMethods(array('getDownloader'))
             ->getMock();
 
         $manager
@@ -154,7 +155,7 @@ class DownloadManagerTest extends TestCase
         $this->assertSame($downloader, $manager->getDownloaderForPackage($package));
     }
 
-    public function testGetDownloaderForIncorrectlyInstalledSourcePackage()
+    public function testGetDownloaderForIncorrectlyInstalledSourcePackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -174,7 +175,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloader'))
+            ->onlyMethods(array('getDownloader'))
             ->getMock();
 
         $manager
@@ -183,12 +184,12 @@ class DownloadManagerTest extends TestCase
             ->with('pear')
             ->will($this->returnValue($downloader));
 
-        $this->setExpectedException('LogicException');
+        self::expectException('LogicException');
 
         $manager->getDownloaderForPackage($package);
     }
 
-    public function testGetDownloaderForMetapackage()
+    public function testGetDownloaderForMetapackage(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -201,7 +202,7 @@ class DownloadManagerTest extends TestCase
         $this->assertNull($manager->getDownloaderForPackage($package));
     }
 
-    public function testFullPackageDownload()
+    public function testFullPackageDownload(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -222,11 +223,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -237,7 +239,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testFullPackageDownloadFailover()
+    public function testFullPackageDownloadFailover(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -254,13 +256,12 @@ class DownloadManagerTest extends TestCase
             ->will($this->returnValue('prettyPackage'));
 
         $package
-            ->expects($this->at(3))
+            ->expects($this->exactly(2))
             ->method('setInstallationSource')
-            ->with('dist');
-        $package
-            ->expects($this->at(5))
-            ->method('setInstallationSource')
-            ->with('source');
+            ->withConsecutive(
+                ['dist'],
+                ['source']
+            );
 
         $downloaderFail = $this->createDownloaderMock();
         $downloaderFail
@@ -273,27 +274,26 @@ class DownloadManagerTest extends TestCase
         $downloaderSuccess
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
-            ->expects($this->at(0))
+            ->expects($this->exactly(2))
             ->method('getDownloaderForPackage')
             ->with($package)
-            ->will($this->returnValue($downloaderFail));
-        $manager
-            ->expects($this->at(1))
-            ->method('getDownloaderForPackage')
-            ->with($package)
-            ->will($this->returnValue($downloaderSuccess));
+            ->willReturnOnConsecutiveCalls(
+                $downloaderFail,
+                $downloaderSuccess
+            );
 
         $manager->download($package, 'target_dir');
     }
 
-    public function testBadPackageDownload()
+    public function testBadPackageDownload(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -307,11 +307,11 @@ class DownloadManagerTest extends TestCase
 
         $manager = new DownloadManager($this->io, false, $this->filesystem);
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
         $manager->download($package, 'target_dir');
     }
 
-    public function testDistOnlyPackageDownload()
+    public function testDistOnlyPackageDownload(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -332,11 +332,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -347,7 +348,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testSourceOnlyPackageDownload()
+    public function testSourceOnlyPackageDownload(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -368,11 +369,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -383,7 +385,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testMetapackagePackageDownload()
+    public function testMetapackagePackageDownload(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -402,7 +404,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
           ->setConstructorArgs(array($this->io, false, $this->filesystem))
-          ->setMethods(array('getDownloaderForPackage'))
+          ->onlyMethods(array('getDownloaderForPackage'))
           ->getMock();
         $manager
           ->expects($this->once())
@@ -413,7 +415,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testFullPackageDownloadWithSourcePreferred()
+    public function testFullPackageDownloadWithSourcePreferred(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -434,11 +436,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -450,7 +453,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testDistOnlyPackageDownloadWithSourcePreferred()
+    public function testDistOnlyPackageDownloadWithSourcePreferred(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -471,11 +474,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -487,7 +491,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testSourceOnlyPackageDownloadWithSourcePreferred()
+    public function testSourceOnlyPackageDownloadWithSourcePreferred(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -508,11 +512,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -524,7 +529,7 @@ class DownloadManagerTest extends TestCase
         $manager->download($package, 'target_dir');
     }
 
-    public function testBadPackageDownloadWithSourcePreferred()
+    public function testBadPackageDownloadWithSourcePreferred(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -539,11 +544,11 @@ class DownloadManagerTest extends TestCase
         $manager = new DownloadManager($this->io, false, $this->filesystem);
         $manager->setPreferSource(true);
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
         $manager->download($package, 'target_dir');
     }
 
-    public function testUpdateDistWithEqualTypes()
+    public function testUpdateDistWithEqualTypes(): void
     {
         $initial = $this->createPackageMock();
         $initial
@@ -569,7 +574,8 @@ class DownloadManagerTest extends TestCase
         $zipDownloader
             ->expects($this->once())
             ->method('update')
-            ->with($initial, $target, 'vendor/bundles/FOS/UserBundle');
+            ->with($initial, $target, 'vendor/bundles/FOS/UserBundle')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
         $zipDownloader
             ->expects($this->any())
             ->method('getInstallationSource')
@@ -581,7 +587,7 @@ class DownloadManagerTest extends TestCase
         $manager->update($initial, $target, 'vendor/bundles/FOS/UserBundle');
     }
 
-    public function testUpdateDistWithNotEqualTypes()
+    public function testUpdateDistWithNotEqualTypes(): void
     {
         $initial = $this->createPackageMock();
         $initial
@@ -607,7 +613,8 @@ class DownloadManagerTest extends TestCase
         $xzDownloader
             ->expects($this->once())
             ->method('remove')
-            ->with($initial, 'vendor/bundles/FOS/UserBundle');
+            ->with($initial, 'vendor/bundles/FOS/UserBundle')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
         $xzDownloader
             ->expects($this->any())
             ->method('getInstallationSource')
@@ -617,7 +624,8 @@ class DownloadManagerTest extends TestCase
         $zipDownloader
             ->expects($this->once())
             ->method('install')
-            ->with($target, 'vendor/bundles/FOS/UserBundle');
+            ->with($target, 'vendor/bundles/FOS/UserBundle')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
         $zipDownloader
             ->expects($this->any())
             ->method('getInstallationSource')
@@ -632,33 +640,43 @@ class DownloadManagerTest extends TestCase
 
     /**
      * @dataProvider updatesProvider
-     * @param ?string $prevPkgSource
-     * @param ?bool $prevPkgIsDev
+     * @param null|string $prevPkgSource
+     * @param null|bool $prevPkgIsDev
      * @param string[] $targetAvailable
      * @param bool $targetIsDev
      * @param string[] $expected
      */
-    public function testGetAvailableSourcesUpdateSticksToSameSource($prevPkgSource, $prevPkgIsDev, $targetAvailable, $targetIsDev, $expected)
+    public function testGetAvailableSourcesUpdateSticksToSameSource(?string $prevPkgSource, ?bool $prevPkgIsDev, array $targetAvailable, bool $targetIsDev, array $expected): void
     {
         $initial = null;
         if ($prevPkgSource) {
-            $initial = $this->prophesize('Composer\Package\PackageInterface');
-            $initial->getInstallationSource()->willReturn($prevPkgSource);
-            $initial->isDev()->willReturn($prevPkgIsDev);
+            $initial = $this->getMockBuilder(PackageInterface::class)->getMock();
+            $initial->expects($this->atLeastOnce())
+                ->method('getInstallationSource')
+                ->willReturn($prevPkgSource);
+            $initial->expects($this->any())
+                ->method('isDev')
+                ->willReturn($prevPkgIsDev);
         }
 
-        $target = $this->prophesize('Composer\Package\PackageInterface');
-        $target->getSourceType()->willReturn(in_array('source', $targetAvailable, true) ? 'git' : null);
-        $target->getDistType()->willReturn(in_array('dist', $targetAvailable, true) ? 'zip' : null);
-        $target->isDev()->willReturn($targetIsDev);
+        $target = $this->getMockBuilder(PackageInterface::class)->getMock();
+        $target->expects($this->atLeastOnce())
+            ->method('getSourceType')
+            ->willReturn(in_array('source', $targetAvailable, true) ? 'git' : null);
+        $target->expects($this->atLeastOnce())
+            ->method('getDistType')
+            ->willReturn(in_array('dist', $targetAvailable, true) ? 'zip' : null);
+        $target->expects($this->any())
+            ->method('isDev')
+            ->willReturn($targetIsDev);
 
         $manager = new DownloadManager($this->io, false, $this->filesystem);
         $method = new \ReflectionMethod($manager, 'getAvailableSources');
         $method->setAccessible(true);
-        $this->assertEquals($expected, $method->invoke($manager, $target->reveal(), $initial ? $initial->reveal() : null));
+        $this->assertEquals($expected, $method->invoke($manager, $target, $initial ?? null));
     }
 
-    public static function updatesProvider()
+    public static function updatesProvider(): array
     {
         return array(
             //    prevPkg source,  prevPkg isDev, pkg available,           pkg isDev,  expected
@@ -681,14 +699,14 @@ class DownloadManagerTest extends TestCase
         );
     }
 
-    public function testUpdateMetapackage()
+    public function testUpdateMetapackage(): void
     {
         $initial = $this->createPackageMock();
         $target = $this->createPackageMock();
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
           ->setConstructorArgs(array($this->io, false, $this->filesystem))
-          ->setMethods(array('getDownloaderForPackage'))
+          ->onlyMethods(array('getDownloaderForPackage'))
           ->getMock();
         $manager
           ->expects($this->exactly(2))
@@ -699,7 +717,7 @@ class DownloadManagerTest extends TestCase
         $manager->update($initial, $target, 'vendor/pkg');
     }
 
-    public function testRemove()
+    public function testRemove(): void
     {
         $package = $this->createPackageMock();
 
@@ -711,7 +729,7 @@ class DownloadManagerTest extends TestCase
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -722,13 +740,13 @@ class DownloadManagerTest extends TestCase
         $manager->remove($package, 'vendor/bundles/FOS/UserBundle');
     }
 
-    public function testMetapackageRemove()
+    public function testMetapackageRemove(): void
     {
         $package = $this->createPackageMock();
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
           ->setConstructorArgs(array($this->io, false, $this->filesystem))
-          ->setMethods(array('getDownloaderForPackage'))
+          ->onlyMethods(array('getDownloaderForPackage'))
           ->getMock();
         $manager
           ->expects($this->once())
@@ -742,7 +760,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithoutPreferenceDev()
+    public function testInstallPreferenceWithoutPreferenceDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -767,11 +785,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -785,7 +804,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithoutPreferenceNoDev()
+    public function testInstallPreferenceWithoutPreferenceNoDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -810,11 +829,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -828,7 +848,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithoutMatchDev()
+    public function testInstallPreferenceWithoutMatchDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -856,11 +876,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -875,7 +896,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithoutMatchNoDev()
+    public function testInstallPreferenceWithoutMatchNoDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -903,11 +924,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -922,7 +944,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithMatchAutoDev()
+    public function testInstallPreferenceWithMatchAutoDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -950,11 +972,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -969,7 +992,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithMatchAutoNoDev()
+    public function testInstallPreferenceWithMatchAutoNoDev(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -997,11 +1020,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -1016,7 +1040,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithMatchSource()
+    public function testInstallPreferenceWithMatchSource(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -1040,11 +1064,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
@@ -1059,7 +1084,7 @@ class DownloadManagerTest extends TestCase
     /**
      * @covers Composer\Downloader\DownloadManager::resolvePackageInstallPreference
      */
-    public function testInstallPreferenceWithMatchDist()
+    public function testInstallPreferenceWithMatchDist(): void
     {
         $package = $this->createPackageMock();
         $package
@@ -1083,11 +1108,12 @@ class DownloadManagerTest extends TestCase
         $downloader
             ->expects($this->once())
             ->method('download')
-            ->with($package, 'target_dir');
+            ->with($package, 'target_dir')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $manager = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->setConstructorArgs(array($this->io, false, $this->filesystem))
-            ->setMethods(array('getDownloaderForPackage'))
+            ->onlyMethods(array('getDownloaderForPackage'))
             ->getMock();
         $manager
             ->expects($this->once())
