@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -18,7 +18,6 @@ use Composer\Pcre\Preg;
 use Composer\Test\TestCase;
 use Composer\Util\Filesystem;
 use Composer\Util\Platform;
-use Composer\Test\Mock\ProcessExecutorMock;
 
 class GitDownloaderTest extends TestCase
 {
@@ -27,18 +26,19 @@ class GitDownloaderTest extends TestCase
     /** @var string */
     private $workingDir;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->skipIfNotExecutable('git');
 
         $this->initGitVersion('1.0.0');
 
         $this->fs = new Filesystem;
-        $this->workingDir = $this->getUniqueTmpDirectory();
+        $this->workingDir = self::getUniqueTmpDirectory();
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         if (is_dir($this->workingDir)) {
             $this->fs->removeDirectory($this->workingDir);
         }
@@ -50,7 +50,7 @@ class GitDownloaderTest extends TestCase
      * @param string|bool $version
      * @return void
      */
-    private function initGitVersion($version)
+    private function initGitVersion($version): void
     {
         // reset the static version cache
         $refl = new \ReflectionProperty('Composer\Util\Git', 'version');
@@ -62,7 +62,7 @@ class GitDownloaderTest extends TestCase
      * @param ?\Composer\Config $config
      * @return \Composer\Config
      */
-    protected function setupConfig($config = null)
+    protected function setupConfig($config = null): Config
     {
         if (!$config) {
             $config = new Config();
@@ -82,24 +82,24 @@ class GitDownloaderTest extends TestCase
      * @param \Composer\Util\Filesystem $filesystem
      * @return GitDownloader
      */
-    protected function getDownloaderMock($io = null, $config = null, $executor = null, $filesystem = null)
+    protected function getDownloaderMock(\Composer\IO\IOInterface $io = null, Config $config = null, \Composer\Test\Mock\ProcessExecutorMock $executor = null, Filesystem $filesystem = null): GitDownloader
     {
         $io = $io ?: $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
-        $executor = $executor ?: new ProcessExecutorMock;
+        $executor = $executor ?: $this->getProcessExecutorMock();
         $filesystem = $filesystem ?: $this->getMockBuilder('Composer\Util\Filesystem')->getMock();
         $config = $this->setupConfig($config);
 
         return new GitDownloader($io, $config, $executor, $filesystem);
     }
 
-    public function testDownloadForPackageWithoutSourceReference()
+    public function testDownloadForPackageWithoutSourceReference(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->once())
             ->method('getSourceReference')
             ->will($this->returnValue(null));
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
 
         $downloader = $this->getDownloaderMock();
         $downloader->download($packageMock, '/path');
@@ -108,7 +108,7 @@ class GitDownloaderTest extends TestCase
         $downloader->cleanup('install', $packageMock, '/path');
     }
 
-    public function testDownload()
+    public function testDownload(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -124,7 +124,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('dev-master'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat("git clone --no-checkout -- 'https://example.com/composer/composer' 'composerPath' && cd 'composerPath' && git remote add composer -- 'https://example.com/composer/composer' && git fetch composer && git remote set-url origin -- 'https://example.com/composer/composer' && git remote set-url composer -- 'https://example.com/composer/composer'"),
             $this->winCompat("git branch -r"),
@@ -136,11 +136,9 @@ class GitDownloaderTest extends TestCase
         $downloader->prepare('install', $packageMock, 'composerPath');
         $downloader->install($packageMock, 'composerPath');
         $downloader->cleanup('install', $packageMock, 'composerPath');
-
-        $process->assertComplete($this);
     }
 
-    public function testDownloadWithCache()
+    public function testDownloadWithCache(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -165,9 +163,9 @@ class GitDownloaderTest extends TestCase
         $filesystem = new \Composer\Util\Filesystem;
         $filesystem->removeDirectory($cachePath);
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
-            array('cmd' => $this->winCompat(sprintf("git clone --mirror -- 'https://example.com/composer/composer' '%s'", $cachePath)), 'callback' => function () use ($cachePath) {
+            array('cmd' => $this->winCompat(sprintf("git clone --mirror -- 'https://example.com/composer/composer' '%s'", $cachePath)), 'callback' => function () use ($cachePath): void {
                 @mkdir($cachePath, 0777, true);
             }),
             array('cmd' => 'git rev-parse --git-dir', 'stdout' => '.'),
@@ -183,11 +181,9 @@ class GitDownloaderTest extends TestCase
         $downloader->install($packageMock, 'composerPath');
         $downloader->cleanup('install', $packageMock, 'composerPath');
         @rmdir($cachePath);
-
-        $process->assertComplete($this);
     }
 
-    public function testDownloadUsesVariousProtocolsAndSetsPushUrlForGithub()
+    public function testDownloadUsesVariousProtocolsAndSetsPushUrlForGithub(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -203,7 +199,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
                 'cmd' => $this->winCompat("git clone --no-checkout -- 'https://github.com/mirrors/composer' 'composerPath' && cd 'composerPath' && git remote add composer -- 'https://github.com/mirrors/composer' && git fetch composer && git remote set-url origin -- 'https://github.com/mirrors/composer' && git remote set-url composer -- 'https://github.com/mirrors/composer'"),
@@ -222,11 +218,9 @@ class GitDownloaderTest extends TestCase
         $downloader->prepare('install', $packageMock, 'composerPath');
         $downloader->install($packageMock, 'composerPath');
         $downloader->cleanup('install', $packageMock, 'composerPath');
-
-        $process->assertComplete($this);
     }
 
-    public function pushUrlProvider()
+    public function pushUrlProvider(): array
     {
         return array(
             // ssh proto should use git@ all along
@@ -244,7 +238,7 @@ class GitDownloaderTest extends TestCase
      * @param string $url
      * @param string $pushUrl
      */
-    public function testDownloadAndSetPushUrlUseCustomVariousProtocolsForGithub($protocols, $url, $pushUrl)
+    public function testDownloadAndSetPushUrlUseCustomVariousProtocolsForGithub(array $protocols, string $url, string $pushUrl): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -260,7 +254,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat("git clone --no-checkout -- '{$url}' 'composerPath' && cd 'composerPath' && git remote add composer -- '{$url}' && git fetch composer && git remote set-url origin -- '{$url}' && git remote set-url composer -- '{$url}'"),
             $this->winCompat("git remote set-url --push origin -- '{$pushUrl}'"),
@@ -276,11 +270,9 @@ class GitDownloaderTest extends TestCase
         $downloader->prepare('install', $packageMock, 'composerPath');
         $downloader->install($packageMock, 'composerPath');
         $downloader->cleanup('install', $packageMock, 'composerPath');
-
-        $process->assertComplete($this);
     }
 
-    public function testDownloadThrowsRuntimeExceptionIfGitCommandFails()
+    public function testDownloadThrowsRuntimeExceptionIfGitCommandFails(): void
     {
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $packageMock->expects($this->any())
@@ -296,7 +288,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             array(
                 'cmd' => $this->winCompat("git clone --no-checkout -- 'https://example.com/composer/composer' 'composerPath' && cd 'composerPath' && git remote add composer -- 'https://example.com/composer/composer' && git fetch composer && git remote set-url origin -- 'https://example.com/composer/composer' && git remote set-url composer -- 'https://example.com/composer/composer'"),
@@ -312,8 +304,6 @@ class GitDownloaderTest extends TestCase
             $downloader->install($packageMock, 'composerPath');
             $downloader->cleanup('install', $packageMock, 'composerPath');
 
-            $process->assertComplete($this);
-
             $this->fail('This test should throw');
         } catch (\RuntimeException $e) {
             if ('RuntimeException' !== get_class($e)) {
@@ -323,7 +313,7 @@ class GitDownloaderTest extends TestCase
         }
     }
 
-    public function testUpdateforPackageWithoutSourceReference()
+    public function testUpdateforPackageWithoutSourceReference(): void
     {
         $initialPackageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $sourcePackageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
@@ -331,7 +321,7 @@ class GitDownloaderTest extends TestCase
             ->method('getSourceReference')
             ->will($this->returnValue(null));
 
-        $this->setExpectedException('InvalidArgumentException');
+        self::expectException('InvalidArgumentException');
 
         $downloader = $this->getDownloaderMock();
         $downloader->download($sourcePackageMock, '/path', $initialPackageMock);
@@ -340,7 +330,7 @@ class GitDownloaderTest extends TestCase
         $downloader->cleanup('update', $sourcePackageMock, '/path', $initialPackageMock);
     }
 
-    public function testUpdate()
+    public function testUpdate(): void
     {
         $expectedGitUpdateCommand = $this->winCompat("(git remote set-url composer -- 'https://github.com/composer/composer' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- 'https://github.com/composer/composer'");
 
@@ -358,7 +348,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat('git show-ref --head -d'),
             $this->winCompat('git status --porcelain --untracked-files=no'),
@@ -375,11 +365,9 @@ class GitDownloaderTest extends TestCase
         $downloader->prepare('update', $packageMock, $this->workingDir, $packageMock);
         $downloader->update($packageMock, $packageMock, $this->workingDir);
         $downloader->cleanup('update', $packageMock, $this->workingDir, $packageMock);
-
-        $process->assertComplete($this);
     }
 
-    public function testUpdateWithNewRepoUrl()
+    public function testUpdateWithNewRepoUrl(): void
     {
         $expectedGitUpdateCommand = $this->winCompat("(git remote set-url composer -- 'https://github.com/composer/composer' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- 'https://github.com/composer/composer'");
 
@@ -400,7 +388,7 @@ class GitDownloaderTest extends TestCase
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat("git show-ref --head -d"),
             $this->winCompat("git status --porcelain --untracked-files=no"),
@@ -426,14 +414,12 @@ composer https://github.com/old/url (push)
         $downloader->prepare('update', $packageMock, $this->workingDir, $packageMock);
         $downloader->update($packageMock, $packageMock, $this->workingDir);
         $downloader->cleanup('update', $packageMock, $this->workingDir, $packageMock);
-
-        $process->assertComplete($this);
     }
 
     /**
      * @group failing
      */
-    public function testUpdateThrowsRuntimeExceptionIfGitCommandFails()
+    public function testUpdateThrowsRuntimeExceptionIfGitCommandFails(): void
     {
         $expectedGitUpdateCommand = $this->winCompat("(git remote set-url composer -- 'https://github.com/composer/composer' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- 'https://github.com/composer/composer'");
         $expectedGitUpdateCommand2 = $this->winCompat("(git remote set-url composer -- 'git@github.com:composer/composer' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- 'git@github.com:composer/composer'");
@@ -449,7 +435,7 @@ composer https://github.com/old/url (push)
             ->method('getVersion')
             ->will($this->returnValue('1.0.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat('git show-ref --head -d'),
             $this->winCompat('git status --porcelain --untracked-files=no'),
@@ -463,7 +449,6 @@ composer https://github.com/old/url (push)
                 'return' => 1,
             ),
             $this->winCompat('git --version'),
-            $this->winCompat('git branch -r'),
         ), true);
 
         $this->fs->ensureDirectoryExists($this->workingDir.'/.git');
@@ -476,8 +461,6 @@ composer https://github.com/old/url (push)
             $downloader->update($packageMock, $packageMock, $this->workingDir);
             $downloader->cleanup('update', $packageMock, $this->workingDir, $packageMock);
 
-            $process->assertComplete($this);
-
             $this->fail('This test should throw');
         } catch (\RuntimeException $e) {
             if ('RuntimeException' !== get_class($e)) {
@@ -487,7 +470,7 @@ composer https://github.com/old/url (push)
         }
     }
 
-    public function testUpdateDoesntThrowsRuntimeExceptionIfGitCommandFailsAtFirstButIsAbleToRecover()
+    public function testUpdateDoesntThrowsRuntimeExceptionIfGitCommandFailsAtFirstButIsAbleToRecover(): void
     {
         $expectedFirstGitUpdateCommand = $this->winCompat("(git remote set-url composer -- '".(Platform::isWindows() ? 'C:\\' : '/')."' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- '".(Platform::isWindows() ? 'C:\\' : '/')."'");
         $expectedSecondGitUpdateCommand = $this->winCompat("(git remote set-url composer -- 'https://github.com/composer/composer' && git rev-parse --quiet --verify 'ref^{commit}' || (git fetch composer && git fetch --tags composer)) && git remote set-url composer -- 'https://github.com/composer/composer'");
@@ -506,7 +489,7 @@ composer https://github.com/old/url (push)
             ->method('getPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $this->winCompat('git show-ref --head -d'),
             $this->winCompat('git status --porcelain --untracked-files=no'),
@@ -532,11 +515,9 @@ composer https://github.com/old/url (push)
         $downloader->prepare('update', $packageMock, $this->workingDir, $packageMock);
         $downloader->update($packageMock, $packageMock, $this->workingDir);
         $downloader->cleanup('update', $packageMock, $this->workingDir, $packageMock);
-
-        $process->assertComplete($this);
     }
 
-    public function testDowngradeShowsAppropriateMessage()
+    public function testDowngradeShowsAppropriateMessage(): void
     {
         $oldPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $oldPackage->expects($this->any())
@@ -569,12 +550,14 @@ composer https://github.com/old/url (push)
             ->method('getFullPrettyVersion')
             ->will($this->returnValue('1.0.0'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
 
         $ioMock = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
-        $ioMock->expects($this->at(0))
+        $ioMock->expects($this->atLeastOnce())
             ->method('writeError')
-            ->with($this->stringContains('Downgrading'));
+            ->withConsecutive(
+                [$this->stringContains('Downgrading')]
+            );
 
         $this->fs->ensureDirectoryExists($this->workingDir.'/.git');
         $downloader = $this->getDownloaderMock($ioMock, null, $process);
@@ -584,7 +567,7 @@ composer https://github.com/old/url (push)
         $downloader->cleanup('update', $newPackage, $this->workingDir, $oldPackage);
     }
 
-    public function testNotUsingDowngradingWithReferences()
+    public function testNotUsingDowngradingWithReferences(): void
     {
         $oldPackage = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
         $oldPackage->expects($this->any())
@@ -611,12 +594,14 @@ composer https://github.com/old/url (push)
             ->method('getPrettyVersion')
             ->will($this->returnValue('dev-ref2'));
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
 
         $ioMock = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
-        $ioMock->expects($this->at(0))
+        $ioMock->expects($this->atLeastOnce())
             ->method('writeError')
-            ->with($this->stringContains('Upgrading'));
+            ->withConsecutive(
+                [$this->stringContains('Upgrading')]
+            );
 
         $this->fs->ensureDirectoryExists($this->workingDir.'/.git');
         $downloader = $this->getDownloaderMock($ioMock, null, $process);
@@ -626,12 +611,12 @@ composer https://github.com/old/url (push)
         $downloader->cleanup('update', $newPackage, $this->workingDir, $oldPackage);
     }
 
-    public function testRemove()
+    public function testRemove(): void
     {
         $expectedGitResetCommand = $this->winCompat("git status --porcelain --untracked-files=no");
 
         $packageMock = $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             'git show-ref --head -d',
             $expectedGitResetCommand,
@@ -649,11 +634,9 @@ composer https://github.com/old/url (push)
         $downloader->prepare('uninstall', $packageMock, $this->workingDir);
         $downloader->remove($packageMock, $this->workingDir);
         $downloader->cleanup('uninstall', $packageMock, $this->workingDir);
-
-        $process->assertComplete($this);
     }
 
-    public function testGetInstallationSource()
+    public function testGetInstallationSource(): void
     {
         $downloader = $this->getDownloaderMock();
 
@@ -664,11 +647,11 @@ composer https://github.com/old/url (push)
      * @param string $cmd
      * @return string
      */
-    private function winCompat($cmd)
+    private function winCompat(string $cmd): string
     {
         if (Platform::isWindows()) {
             $cmd = str_replace('cd ', 'cd /D ', $cmd);
-            $cmd = str_replace('composerPath', getcwd().'/composerPath', $cmd);
+            $cmd = str_replace('composerPath', Platform::getCwd().'/composerPath', $cmd);
 
             return $this->getCmd($cmd);
         }
