@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -23,32 +23,30 @@ use Composer\IO\BufferIO;
 use Composer\Script\ScriptEvents;
 use Composer\Script\Event as ScriptEvent;
 use Composer\Util\ProcessExecutor;
-use Composer\Test\Mock\ProcessExecutorMock;
 use Composer\Util\Platform;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class EventDispatcherTest extends TestCase
 {
-    public function testListenerExceptionsAreCaught()
+    public function testListenerExceptionsAreCaught(): void
     {
-        $this->setExpectedException('RuntimeException');
+        self::expectException('RuntimeException');
 
         $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $dispatcher = $this->getDispatcherStubForListenersTest(array(
             'Composer\Test\EventDispatcher\EventDispatcherTest::call',
         ), $io);
 
-        $io->expects($this->at(0))
+        $io->expects($this->once())
             ->method('isVerbose')
             ->willReturn(0);
 
-        $io->expects($this->at(1))
+        $io->expects($this->atLeast(2))
             ->method('writeError')
-            ->with('> Composer\Test\EventDispatcher\EventDispatcherTest::call');
-
-        $io->expects($this->at(2))
-            ->method('writeError')
-            ->with('<error>Script Composer\Test\EventDispatcher\EventDispatcherTest::call handling the post-install-cmd event terminated with an exception</error>');
+            ->withConsecutive(
+                ['> Composer\Test\EventDispatcher\EventDispatcherTest::call'],
+                ['<error>Script Composer\Test\EventDispatcher\EventDispatcherTest::call handling the post-install-cmd event terminated with an exception</error>']
+            );
 
         $dispatcher->dispatchScript(ScriptEvents::POST_INSTALL_CMD, false);
     }
@@ -58,9 +56,9 @@ class EventDispatcherTest extends TestCase
      *
      * @param string $command
      */
-    public function testDispatcherCanExecuteSingleCommandLineScript($command)
+    public function testDispatcherCanExecuteSingleCommandLineScript(string $command): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             $command,
         ), true);
@@ -71,7 +69,7 @@ class EventDispatcherTest extends TestCase
                 $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
                 $process,
             ))
-            ->setMethods(array('getListeners'))
+            ->onlyMethods(array('getListeners'))
             ->getMock();
 
         $listener = array($command);
@@ -80,8 +78,6 @@ class EventDispatcherTest extends TestCase
             ->will($this->returnValue($listener));
 
         $dispatcher->dispatchScript(ScriptEvents::POST_INSTALL_CMD, false);
-
-        $process->assertComplete($this);
     }
 
     /**
@@ -89,7 +85,7 @@ class EventDispatcherTest extends TestCase
      *
      * @param bool $devMode
      */
-    public function testDispatcherPassDevModeToAutoloadGeneratorForScriptEvents($devMode)
+    public function testDispatcherPassDevModeToAutoloadGeneratorForScriptEvents(bool $devMode): void
     {
         $composer = $this->createComposerInstance();
 
@@ -110,7 +106,7 @@ class EventDispatcherTest extends TestCase
         $dispatcher = new EventDispatcher(
             $composer,
             $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
-            new ProcessExecutorMock
+            $this->getProcessExecutorMock()
         );
 
         $event = $this->getMockBuilder('Composer\Script\Event')
@@ -124,7 +120,7 @@ class EventDispatcherTest extends TestCase
         $dispatcher->hasEventListeners($event);
     }
 
-    public function provideDevModes()
+    public function provideDevModes(): array
     {
         return array(
             array(true),
@@ -139,7 +135,7 @@ class EventDispatcherTest extends TestCase
     {
         $generator = $this->getMockBuilder('Composer\Autoload\AutoloadGenerator')
             ->disableOriginalConstructor()
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'buildPackageMap',
                 'parseAutoloads',
                 'createLoader',
@@ -151,7 +147,7 @@ class EventDispatcherTest extends TestCase
             ->will($this->returnValue(array()));
         $generator
             ->method('parseAutoloads')
-            ->will($this->returnValue(array('psr-0' => array(), 'psr-4' => array(), 'classmap' => array(), 'files' => array(), 'exclude-from-classmap' => array(),)));
+            ->will($this->returnValue(array('psr-0' => array(), 'psr-4' => array(), 'classmap' => array(), 'files' => array(), 'exclude-from-classmap' => array())));
         $generator
             ->method('createLoader')
             ->will($this->returnValue($this->getMockBuilder('Composer\Autoload\ClassLoader')->getMock()));
@@ -166,7 +162,7 @@ class EventDispatcherTest extends TestCase
     {
         $rm = $this->getMockBuilder('Composer\Repository\RepositoryManager')
             ->disableOriginalConstructor()
-            ->setMethods(array('getLocalRepository'))
+            ->onlyMethods(array('getLocalRepository'))
             ->getMock();
 
         $repo = $this->getMockBuilder('Composer\Repository\InstalledRepositoryInterface')->getMock();
@@ -181,7 +177,7 @@ class EventDispatcherTest extends TestCase
         return $rm;
     }
 
-    public function testDispatcherRemoveListener()
+    public function testDispatcherRemoveListener(): void
     {
         $composer = $this->createComposerInstance();
 
@@ -191,7 +187,7 @@ class EventDispatcherTest extends TestCase
         $dispatcher = new EventDispatcher(
             $composer,
             $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
-            new ProcessExecutorMock
+            $this->getProcessExecutorMock()
         );
 
         $listener = array($this, 'someMethod');
@@ -224,9 +220,9 @@ class EventDispatcherTest extends TestCase
         $this->assertEquals($expected, $io->getOutput());
     }
 
-    public function testDispatcherCanExecuteCliAndPhpInSameEventScriptStack()
+    public function testDispatcherCanExecuteCliAndPhpInSameEventScriptStack(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             'echo -n foo',
             'echo -n bar',
@@ -238,7 +234,7 @@ class EventDispatcherTest extends TestCase
                 $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
                 $process,
             ))
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'getListeners',
             ))
             ->getMock();
@@ -259,19 +255,17 @@ class EventDispatcherTest extends TestCase
             '> post-install-cmd: Composer\Test\EventDispatcher\EventDispatcherTest::someMethod'.PHP_EOL.
             '> post-install-cmd: echo -n bar'.PHP_EOL;
         $this->assertEquals($expected, $io->getOutput());
-
-        $process->assertComplete($this);
     }
 
-    public function testDispatcherCanPutEnv()
+    public function testDispatcherCanPutEnv(): void
     {
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->setConstructorArgs(array(
                 $this->createComposerInstance(),
                 $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
-                new ProcessExecutorMock,
+                $this->getProcessExecutorMock(),
             ))
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'getListeners',
             ))
             ->getMock();
@@ -292,9 +286,9 @@ class EventDispatcherTest extends TestCase
         $this->assertEquals($expected, $io->getOutput());
     }
 
-    public function testDispatcherAppendsDirBinOnPathForEveryListener()
+    public function testDispatcherAppendsDirBinOnPathForEveryListener(): void
     {
-        $currentDirectoryBkp = getcwd();
+        $currentDirectoryBkp = Platform::getCwd();
         $composerBinDirBkp = Platform::getEnv('COMPOSER_BIN_DIR');
         chdir(__DIR__);
         Platform::putEnv('COMPOSER_BIN_DIR', __DIR__ . '/vendor/bin');
@@ -302,8 +296,8 @@ class EventDispatcherTest extends TestCase
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')->setConstructorArgs(array(
                 $this->createComposerInstance(),
                 $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
-                new ProcessExecutorMock,
-            ))->setMethods(array(
+                $this->getProcessExecutorMock(),
+            ))->onlyMethods(array(
                 'getListeners',
             ))->getMock();
 
@@ -329,7 +323,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return void
      */
-    public static function createsVendorBinFolderChecksEnvDoesNotContainsBin()
+    public static function createsVendorBinFolderChecksEnvDoesNotContainsBin(): void
     {
         mkdir(__DIR__ . '/vendor/bin', 0700, true);
         $val = getenv('PATH');
@@ -344,7 +338,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return void
      */
-    public static function createsVendorBinFolderChecksEnvContainsBin()
+    public static function createsVendorBinFolderChecksEnvContainsBin(): void
     {
         $val = getenv('PATH');
 
@@ -358,7 +352,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return void
      */
-    public static function getTestEnv()
+    public static function getTestEnv(): void
     {
         $val = getenv('ABC');
         if ($val !== '123') {
@@ -366,9 +360,9 @@ class EventDispatcherTest extends TestCase
         }
     }
 
-    public function testDispatcherCanExecuteComposerScriptGroups()
+    public function testDispatcherCanExecuteComposerScriptGroups(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             'echo -n foo',
             'echo -n baz',
@@ -381,14 +375,14 @@ class EventDispatcherTest extends TestCase
                 $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
                 $process,
             ))
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'getListeners',
             ))
             ->getMock();
 
         $dispatcher->expects($this->atLeastOnce())
             ->method('getListeners')
-            ->will($this->returnCallback(function (Event $event) {
+            ->will($this->returnCallback(function (Event $event): array {
                 if ($event->getName() === 'root') {
                     return array('@group');
                 }
@@ -411,13 +405,11 @@ class EventDispatcherTest extends TestCase
             '> subgroup: echo -n baz'.PHP_EOL.
             '> group: echo -n bar'.PHP_EOL;
         $this->assertEquals($expected, $io->getOutput());
-
-        $process->assertComplete($this);
     }
 
-    public function testRecursionInScriptsNames()
+    public function testRecursionInScriptsNames(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(
             'echo Hello '.ProcessExecutor::escape('World'),
         ), true);
@@ -428,14 +420,14 @@ class EventDispatcherTest extends TestCase
                 $io = new BufferIO('', OutputInterface::VERBOSITY_VERBOSE),
                 $process,
             ))
-            ->setMethods(array(
+            ->onlyMethods(array(
                 'getListeners',
             ))
             ->getMock();
 
         $dispatcher->expects($this->atLeastOnce())
             ->method('getListeners')
-            ->will($this->returnCallback(function (Event $event) {
+            ->will($this->returnCallback(function (Event $event): array {
                 if ($event->getName() === 'hello') {
                     return array('echo Hello');
                 }
@@ -452,28 +444,26 @@ class EventDispatcherTest extends TestCase
             "> hello: echo Hello " .$this->getCmd("'World'").PHP_EOL;
 
         $this->assertEquals($expected, $io->getOutput());
-
-        $process->assertComplete($this);
     }
 
-    public function testDispatcherDetectInfiniteRecursion()
+    public function testDispatcherDetectInfiniteRecursion(): void
     {
-        $this->setExpectedException('RuntimeException');
+        self::expectException('RuntimeException');
 
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
         ->setConstructorArgs(array(
             $composer = $this->createComposerInstance(),
             $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
-            new ProcessExecutorMock,
+            $this->getProcessExecutorMock(),
         ))
-        ->setMethods(array(
+        ->onlyMethods(array(
             'getListeners',
         ))
         ->getMock();
 
         $dispatcher->expects($this->atLeastOnce())
             ->method('getListeners')
-            ->will($this->returnCallback(function (Event $event) {
+            ->will($this->returnCallback(function (Event $event): array {
                 if ($event->getName() === 'root') {
                     return array('@recurse');
                 }
@@ -493,14 +483,14 @@ class EventDispatcherTest extends TestCase
      *
      * @return \PHPUnit\Framework\MockObject\MockObject&\Composer\EventDispatcher\EventDispatcher
      */
-    private function getDispatcherStubForListenersTest($listeners, IOInterface $io)
+    private function getDispatcherStubForListenersTest(array $listeners, IOInterface $io)
     {
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->setConstructorArgs(array(
                 $this->createComposerInstance(),
                 $io,
             ))
-            ->setMethods(array('getListeners'))
+            ->onlyMethods(array('getListeners'))
             ->getMock();
 
         $dispatcher->expects($this->atLeastOnce())
@@ -510,7 +500,7 @@ class EventDispatcherTest extends TestCase
         return $dispatcher;
     }
 
-    public function provideValidCommands()
+    public function provideValidCommands(): array
     {
         return array(
             array('phpunit'),
@@ -519,7 +509,7 @@ class EventDispatcherTest extends TestCase
         );
     }
 
-    public function testDispatcherOutputsCommand()
+    public function testDispatcherOutputsCommand(): void
     {
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->setConstructorArgs(array(
@@ -527,7 +517,7 @@ class EventDispatcherTest extends TestCase
                 $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
                 new ProcessExecutor($io),
             ))
-            ->setMethods(array('getListeners'))
+            ->onlyMethods(array('getListeners'))
             ->getMock();
 
         $listener = array('echo foo');
@@ -546,7 +536,7 @@ class EventDispatcherTest extends TestCase
         $dispatcher->dispatchScript(ScriptEvents::POST_INSTALL_CMD, false);
     }
 
-    public function testDispatcherOutputsErrorOnFailedCommand()
+    public function testDispatcherOutputsErrorOnFailedCommand(): void
     {
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->setConstructorArgs(array(
@@ -554,7 +544,7 @@ class EventDispatcherTest extends TestCase
                 $io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
                 new ProcessExecutor,
             ))
-            ->setMethods(array('getListeners'))
+            ->onlyMethods(array('getListeners'))
             ->getMock();
 
         $code = 'exit 1';
@@ -563,35 +553,34 @@ class EventDispatcherTest extends TestCase
             ->method('getListeners')
             ->will($this->returnValue($listener));
 
-        $io->expects($this->at(0))
+        $io->expects($this->once())
             ->method('isVerbose')
             ->willReturn(0);
 
-        $io->expects($this->at(1))
+        $io->expects($this->atLeast(2))
             ->method('writeError')
-            ->willReturn('> exit 1');
+            ->withConsecutive(
+                ['> exit 1'],
+                ['<error>Script '.$code.' handling the post-install-cmd event returned with error code 1</error>']
+            );
 
-        $io->expects($this->at(2))
+        $io->expects($this->once())
             ->method('isInteractive')
             ->willReturn(1);
 
-        $io->expects($this->at(3))
-            ->method('writeError')
-            ->with($this->equalTo('<error>Script '.$code.' handling the post-install-cmd event returned with error code 1</error>'));
-
-        $this->setExpectedException('RuntimeException');
+        self::expectException('RuntimeException');
         $dispatcher->dispatchScript(ScriptEvents::POST_INSTALL_CMD, false);
     }
 
-    public function testDispatcherInstallerEvents()
+    public function testDispatcherInstallerEvents(): void
     {
         $dispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->setConstructorArgs(array(
                     $this->createComposerInstance(),
                     $this->getMockBuilder('Composer\IO\IOInterface')->getMock(),
-                    new ProcessExecutorMock,
+                    $this->getProcessExecutorMock(),
                 ))
-            ->setMethods(array('getListeners'))
+            ->onlyMethods(array('getListeners'))
             ->getMock();
 
         $dispatcher->expects($this->atLeastOnce())
@@ -606,7 +595,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return void
      */
-    public static function call()
+    public static function call(): void
     {
         throw new \RuntimeException();
     }
@@ -614,7 +603,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return true
      */
-    public static function someMethod()
+    public static function someMethod(): bool
     {
         return true;
     }
@@ -622,7 +611,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return true
      */
-    public static function someMethod2()
+    public static function someMethod2(): bool
     {
         return true;
     }
@@ -630,7 +619,7 @@ class EventDispatcherTest extends TestCase
     /**
      * @return Composer
      */
-    private function createComposerInstance()
+    private function createComposerInstance(): Composer
     {
         $composer = new Composer;
         $config = new Config();
