@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -18,7 +18,7 @@ use Symfony\Component\Console\Input\StreamableInputInterface;
 
 class BufferIOTest extends TestCase
 {
-    public function testSetUserInputs()
+    public function testSetUserInputs(): void
     {
         $bufferIO = new BufferIO();
 
@@ -27,7 +27,8 @@ class BufferIOTest extends TestCase
         $input = $refl->getValue($bufferIO);
 
         if (!$input instanceof StreamableInputInterface) {
-            $this->setExpectedException('\RuntimeException', 'Setting the user inputs requires at least the version 3.2 of the symfony/console component.');
+            self::expectException('\RuntimeException');
+            self::expectExceptionMessage('Setting the user inputs requires at least the version 3.2 of the symfony/console component.');
         }
 
         $bufferIO->setUserInputs(array(
