@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -34,15 +34,16 @@ abstract class ArchiverTest extends TestCase
      */
     protected $testDir;
 
-    public function setUp()
+    public function setUp(): void
     {
         $this->filesystem = new Filesystem();
         $this->process = new ProcessExecutor();
-        $this->testDir = $this->getUniqueTmpDirectory();
+        $this->testDir = self::getUniqueTmpDirectory();
     }
 
-    public function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         $this->filesystem->removeDirectory($this->testDir);
     }
 
@@ -51,10 +52,10 @@ abstract class ArchiverTest extends TestCase
      *
      * @return CompletePackage
      */
-    protected function setupPackage()
+    protected function setupPackage(): CompletePackage
     {
         $package = new CompletePackage('archivertest/archivertest', 'master', 'master');
-        $package->setSourceUrl(realpath($this->testDir));
+        $package->setSourceUrl((string) realpath($this->testDir));
         $package->setSourceReference('master');
         $package->setSourceType('git');
 
