@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -12,6 +12,7 @@
 
 namespace Composer\Test\Package;
 
+use Composer\Json\JsonFile;
 use Composer\Package\Locker;
 use Composer\Plugin\PluginInterface;
 use Composer\IO\NullIO;
@@ -19,7 +20,7 @@ use Composer\Test\TestCase;
 
 class LockerTest extends TestCase
 {
-    public function testIsLocked()
+    public function testIsLocked(): void
     {
         $json = $this->createJsonFileMock();
         $locker = new Locker(
@@ -41,7 +42,7 @@ class LockerTest extends TestCase
         $this->assertTrue($locker->isLocked());
     }
 
-    public function testGetNotLockedPackages()
+    public function testGetNotLockedPackages(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -53,12 +54,12 @@ class LockerTest extends TestCase
             ->method('exists')
             ->will($this->returnValue(false));
 
-        $this->setExpectedException('LogicException');
+        self::expectException('LogicException');
 
         $locker->getLockedRepository();
     }
 
-    public function testGetLockedPackages()
+    public function testGetLockedPackages(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -84,7 +85,7 @@ class LockerTest extends TestCase
         $this->assertNotNull($repo->findPackage('pkg2', '0.1.10'));
     }
 
-    public function testSetLockData()
+    public function testSetLockData(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -92,41 +93,8 @@ class LockerTest extends TestCase
         $jsonContent = $this->getJsonContent() . '  ';
         $locker = new Locker(new NullIO, $json, $inst, $jsonContent);
 
-        $package1 = $this->createPackageMock();
-        $package2 = $this->createPackageMock();
-
-        $package1
-            ->expects($this->atLeastOnce())
-            ->method('getPrettyName')
-            ->will($this->returnValue('pkg1'));
-        $package1
-            ->expects($this->atLeastOnce())
-            ->method('getPrettyVersion')
-            ->will($this->returnValue('1.0.0-beta'));
-        $package1
-            ->expects($this->atLeastOnce())
-            ->method('getVersion')
-            ->will($this->returnValue('1.0.0.0-beta'));
-
-        $package2
-            ->expects($this->atLeastOnce())
-            ->method('getPrettyName')
-            ->will($this->returnValue('pkg2'));
-        $package2
-            ->expects($this->atLeastOnce())
-            ->method('getPrettyVersion')
-            ->will($this->returnValue('0.1.10'));
-        $package2
-            ->expects($this->atLeastOnce())
-            ->method('getVersion')
-            ->will($this->returnValue('0.1.10.0'));
-
-        foreach (array($package1, $package2) as $package) {
-            $package
-                ->expects($this->atLeastOnce())
-                ->method('getTransportOptions')
-                ->will($this->returnValue(array()));
-        }
+        $package1 = $this->getPackage('pkg1', '1.0.0-beta');
+        $package2 = $this->getPackage('pkg2', '0.1.10');
 
         $contentHash = md5(trim($jsonContent));
 
@@ -139,8 +107,8 @@ class LockerTest extends TestCase
                                    'This file is @gener'.'ated automatically', ),
                 'content-hash' => $contentHash,
                 'packages' => array(
-                    array('name' => 'pkg1', 'version' => '1.0.0-beta'),
-                    array('name' => 'pkg2', 'version' => '0.1.10'),
+                    array('name' => 'pkg1', 'version' => '1.0.0-beta', 'type' => 'library'),
+                    array('name' => 'pkg2', 'version' => '0.1.10', 'type' => 'library'),
                 ),
                 'packages-dev' => array(),
                 'aliases' => array(),
@@ -157,7 +125,7 @@ class LockerTest extends TestCase
         $locker->setLockData(array($package1, $package2), array(), array(), array(), array(), 'dev', array(), false, false, array('foo/bar' => '1.0'));
     }
 
-    public function testLockBadPackages()
+    public function testLockBadPackages(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -170,12 +138,12 @@ class LockerTest extends TestCase
             ->method('getPrettyName')
             ->will($this->returnValue('pkg1'));
 
-        $this->setExpectedException('LogicException');
+        self::expectException('LogicException');
 
         $locker->setLockData(array($package1), array(), array(), array(), array(), 'dev', array(), false, false, array());
     }
 
-    public function testIsFresh()
+    public function testIsFresh(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -191,7 +159,7 @@ class LockerTest extends TestCase
         $this->assertTrue($locker->isFresh());
     }
 
-    public function testIsFreshFalse()
+    public function testIsFreshFalse(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -206,7 +174,7 @@ class LockerTest extends TestCase
         $this->assertFalse($locker->isFresh());
     }
 
-    public function testIsFreshWithContentHash()
+    public function testIsFreshWithContentHash(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -222,7 +190,7 @@ class LockerTest extends TestCase
         $this->assertTrue($locker->isFresh());
     }
 
-    public function testIsFreshWithContentHashAndNoHash()
+    public function testIsFreshWithContentHashAndNoHash(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -238,7 +206,7 @@ class LockerTest extends TestCase
         $this->assertTrue($locker->isFresh());
     }
 
-    public function testIsFreshFalseWithContentHash()
+    public function testIsFreshFalseWithContentHash(): void
     {
         $json = $this->createJsonFileMock();
         $inst = $this->createInstallationManagerMock();
@@ -282,16 +250,13 @@ class LockerTest extends TestCase
      */
     private function createPackageMock()
     {
-        return $this->getMockBuilder('Composer\Package\PackageInterface')
-            ->getMock();
+        return $this->getMockBuilder('Composer\Package\PackageInterface')->getMock();
     }
 
     /**
      * @param array<string, string> $customData
-     *
-     * @return false|string
      */
-    private function getJsonContent(array $customData = array())
+    private function getJsonContent(array $customData = array()): string
     {
         $data = array_merge(array(
             'minimum-stability' => 'beta',
@@ -300,6 +265,6 @@ class LockerTest extends TestCase
 
         ksort($data);
 
-        return json_encode($data);
+        return JsonFile::encode($data, 0);
     }
 }
