@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -69,11 +69,11 @@ class PluginInstallerTest extends TestCase
      */
     protected $io;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $loader = new JsonLoader(new ArrayLoader());
         $this->packages = array();
-        $this->directory = $this->getUniqueTmpDirectory();
+        $this->directory = self::getUniqueTmpDirectory();
         for ($i = 1; $i <= 8; $i++) {
             $filename = '/Fixtures/plugin-v'.$i.'/composer.json';
             mkdir(dirname($this->directory . $filename), 0777, true);
@@ -83,6 +83,15 @@ class PluginInstallerTest extends TestCase
         $dm = $this->getMockBuilder('Composer\Downloader\DownloadManager')
             ->disableOriginalConstructor()
             ->getMock();
+        $dm->expects($this->any())
+            ->method('install')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
+        $dm->expects($this->any())
+            ->method('update')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
+        $dm->expects($this->any())
+            ->method('remove')
+            ->will($this->returnValue(\React\Promise\resolve(null)));
 
         $this->repository = $this->getMockBuilder('Composer\Repository\InstalledRepositoryInterface')->getMock();
 
@@ -96,7 +105,7 @@ class PluginInstallerTest extends TestCase
         $im = $this->getMockBuilder('Composer\Installer\InstallationManager')->disableOriginalConstructor()->getMock();
         $im->expects($this->any())
             ->method('getInstallPath')
-            ->will($this->returnCallback(function ($package) {
+            ->will($this->returnCallback(function ($package): string {
                 return __DIR__.'/Fixtures/'.$package->getPrettyName();
             }));
 
@@ -128,13 +137,14 @@ class PluginInstallerTest extends TestCase
         $this->composer->setPluginManager($this->pm);
     }
 
-    protected function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         $filesystem = new Filesystem();
         $filesystem->removeDirectory($this->directory);
     }
 
-    public function testInstallNewPlugin()
+    public function testInstallNewPlugin(): void
     {
         $this->repository
             ->expects($this->any())
@@ -153,7 +163,7 @@ class PluginInstallerTest extends TestCase
         );
     }
 
-    public function testInstallPluginWithRootPackageHavingFilesAutoload()
+    public function testInstallPluginWithRootPackageHavingFilesAutoload(): void
     {
         $this->repository
             ->expects($this->any())
@@ -175,7 +185,7 @@ class PluginInstallerTest extends TestCase
         $this->assertEquals('installer-v1', $plugins[0]->version);  // @phpstan-ignore-line
     }
 
-    public function testInstallMultiplePlugins()
+    public function testInstallMultiplePlugins(): void
     {
         $this->repository
             ->expects($this->any())
@@ -194,7 +204,7 @@ class PluginInstallerTest extends TestCase
         $this->assertEquals('activate v4-plugin1'.PHP_EOL.'activate v4-plugin2'.PHP_EOL, $this->io->getOutput());
     }
 
-    public function testUpgradeWithNewClassName()
+    public function testUpgradeWithNewClassName(): void
     {
         $this->repository
             ->expects($this->any())
@@ -215,7 +225,7 @@ class PluginInstallerTest extends TestCase
         $this->assertEquals('activate v1'.PHP_EOL.'deactivate v1'.PHP_EOL.'activate v2'.PHP_EOL, $this->io->getOutput());
     }
 
-    public function testUninstall()
+    public function testUninstall(): void
     {
         $this->repository
             ->expects($this->any())
@@ -235,7 +245,7 @@ class PluginInstallerTest extends TestCase
         $this->assertEquals('activate v1'.PHP_EOL.'deactivate v1'.PHP_EOL.'uninstall v1'.PHP_EOL, $this->io->getOutput());
     }
 
-    public function testUpgradeWithSameClassName()
+    public function testUpgradeWithSameClassName(): void
     {
         $this->repository
             ->expects($this->any())
@@ -255,7 +265,7 @@ class PluginInstallerTest extends TestCase
         $this->assertEquals('activate v2'.PHP_EOL.'deactivate v2'.PHP_EOL.'activate v3'.PHP_EOL, $this->io->getOutput());
     }
 
-    public function testRegisterPluginOnlyOneTime()
+    public function testRegisterPluginOnlyOneTime(): void
     {
         $this->repository
             ->expects($this->any())
@@ -279,11 +289,11 @@ class PluginInstallerTest extends TestCase
      *
      * @return void
      */
-    private function setPluginApiVersionWithPlugins($newPluginApiVersion, array $plugins = array())
+    private function setPluginApiVersionWithPlugins(string $newPluginApiVersion, array $plugins = array()): void
     {
         // reset the plugin manager's installed plugins
         $this->pm = $this->getMockBuilder('Composer\Plugin\PluginManager')
-                         ->setMethods(array('getPluginApiVersion'))
+                         ->onlyMethods(array('getPluginApiVersion'))
                          ->setConstructorArgs(array($this->io, $this->composer))
                          ->getMock();
 
@@ -302,14 +312,14 @@ class PluginInstallerTest extends TestCase
         $this->repository
             ->expects($this->any())
             ->method('getPackages')
-            ->will($this->returnCallback(function () use ($plugApiInternalPackage, $plugins) {
+            ->will($this->returnCallback(function () use ($plugApiInternalPackage, $plugins): array {
                 return array_merge(array($plugApiInternalPackage), $plugins);
             }));
 
         $this->pm->loadInstalledPlugins();
     }
 
-    public function testStarPluginVersionWorksWithAnyAPIVersion()
+    public function testStarPluginVersionWorksWithAnyAPIVersion(): void
     {
         $starVersionPlugin = array($this->packages[4]);
 
@@ -326,7 +336,7 @@ class PluginInstallerTest extends TestCase
         $this->assertCount(1, $this->pm->getPlugins());
     }
 
-    public function testPluginConstraintWorksOnlyWithCertainAPIVersion()
+    public function testPluginConstraintWorksOnlyWithCertainAPIVersion(): void
     {
         $pluginWithApiConstraint = array($this->packages[5]);
 
@@ -343,7 +353,7 @@ class PluginInstallerTest extends TestCase
         $this->assertCount(1, $this->pm->getPlugins());
     }
 
-    public function testPluginRangeConstraintsWorkOnlyWithCertainAPIVersion()
+    public function testPluginRangeConstraintsWorkOnlyWithCertainAPIVersion(): void
     {
         $pluginWithApiConstraint = array($this->packages[6]);
 
@@ -357,7 +367,7 @@ class PluginInstallerTest extends TestCase
         $this->assertCount(0, $this->pm->getPlugins());
     }
 
-    public function testCommandProviderCapability()
+    public function testCommandProviderCapability(): void
     {
         $this->repository
             ->expects($this->any())
@@ -376,14 +386,14 @@ class PluginInstallerTest extends TestCase
         $this->assertInstanceOf('Composer\Command\BaseCommand', $commands[0]);
     }
 
-    public function testIncapablePluginIsCorrectlyDetected()
+    public function testIncapablePluginIsCorrectlyDetected(): void
     {
         $plugin = $this->getMockBuilder('Composer\Plugin\PluginInterface')
                        ->getMock();
         $this->assertNull($this->pm->getPluginCapability($plugin, 'Fake\Ability'));
     }
 
-    public function testCapabilityImplementsComposerPluginApiClassAndIsConstructedWithArgs()
+    public function testCapabilityImplementsComposerPluginApiClassAndIsConstructedWithArgs(): void
     {
         $capabilityApi = 'Composer\Plugin\Capability\Capability';
         $capabilityImplementation = 'Composer\Test\Plugin\Mock\Capability';
@@ -393,7 +403,7 @@ class PluginInstallerTest extends TestCase
 
         $plugin->expects($this->once())
                ->method('getCapabilities')
-               ->will($this->returnCallback(function () use ($capabilityImplementation, $capabilityApi) {
+               ->will($this->returnCallback(function () use ($capabilityImplementation, $capabilityApi): array {
                    return array($capabilityApi => $capabilityImplementation);
                }));
 
@@ -406,7 +416,7 @@ class PluginInstallerTest extends TestCase
     }
 
     /** @return mixed[] */
-    public function invalidImplementationClassNames()
+    public function invalidImplementationClassNames(): array
     {
         return array(
             array(null),
@@ -420,25 +430,14 @@ class PluginInstallerTest extends TestCase
         );
     }
 
-    /** @return mixed[] */
-    public function nonExistingOrInvalidImplementationClassTypes()
-    {
-        return array(
-            array('\stdClass'),
-            array('NonExistentClassLikeMiddleClass'),
-        );
-    }
-
     /**
      * @dataProvider invalidImplementationClassNames
-     * @param callable $invalidImplementationClassNames
-     * @param string $expect
-     *
-     * @return void
+     * @param mixed $invalidImplementationClassNames
+     * @param class-string<\Throwable> $expect
      */
-    public function testQueryingWithInvalidCapabilityClassNameThrows($invalidImplementationClassNames, $expect = 'UnexpectedValueException')
+    public function testQueryingWithInvalidCapabilityClassNameThrows($invalidImplementationClassNames, string $expect = 'UnexpectedValueException'): void
     {
-        $this->setExpectedException($expect);
+        self::expectException($expect);
 
         $capabilityApi = 'Composer\Plugin\Capability\Capability';
 
@@ -447,15 +446,14 @@ class PluginInstallerTest extends TestCase
 
         $plugin->expects($this->once())
                ->method('getCapabilities')
-               ->will($this->returnCallback(function () use ($invalidImplementationClassNames, $capabilityApi) {
+               ->will($this->returnCallback(function () use ($invalidImplementationClassNames, $capabilityApi): array {
                    return array($capabilityApi => $invalidImplementationClassNames);
                }));
 
         $this->pm->getPluginCapability($plugin, $capabilityApi);
     }
 
-    /** @return void */
-    public function testQueryingNonProvidedCapabilityReturnsNullSafely()
+    public function testQueryingNonProvidedCapabilityReturnsNullSafely(): void
     {
         $capabilityApi = 'Composer\Plugin\Capability\MadeUpCapability';
 
@@ -464,20 +462,26 @@ class PluginInstallerTest extends TestCase
 
         $plugin->expects($this->once())
                ->method('getCapabilities')
-               ->will($this->returnCallback(function () {
+               ->will($this->returnCallback(function (): array {
                    return array();
                }));
 
         $this->assertNull($this->pm->getPluginCapability($plugin, $capabilityApi));
     }
 
+    /** @return mixed[] */
+    public function nonExistingOrInvalidImplementationClassTypes(): array
+    {
+        return array(
+            array('\stdClass'),
+            array('NonExistentClassLikeMiddleClass'),
+        );
+    }
+
     /**
      * @dataProvider nonExistingOrInvalidImplementationClassTypes
-     * @param callable $wrongImplementationClassTypes
-     *
-     * @return void
      */
-    public function testQueryingWithNonExistingOrWrongCapabilityClassTypesThrows($wrongImplementationClassTypes)
+    public function testQueryingWithNonExistingOrWrongCapabilityClassTypesThrows(string $wrongImplementationClassTypes): void
     {
         $this->testQueryingWithInvalidCapabilityClassNameThrows($wrongImplementationClassTypes, 'RuntimeException');
     }
