@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -16,7 +16,6 @@ use Composer\Question\StrictConfirmationQuestion;
 use Composer\Test\TestCase;
 use Symfony\Component\Console\Helper\QuestionHelper;
 use Symfony\Component\Console\Input\ArrayInput;
-use Symfony\Component\Console\Input\StreamableInputInterface;
 use Symfony\Component\Console\Output\StreamOutput;
 
 /**
@@ -31,7 +30,7 @@ class StrictConfirmationQuestionTest extends TestCase
      *
      * @phpstan-return list<array{non-empty-string}>
      */
-    public function getAskConfirmationBadData()
+    public function getAskConfirmationBadData(): array
     {
         return array(
             array('not correct'),
@@ -46,11 +45,12 @@ class StrictConfirmationQuestionTest extends TestCase
      *
      * @param string $answer
      */
-    public function testAskConfirmationBadAnswer($answer)
+    public function testAskConfirmationBadAnswer(string $answer): void
     {
         list($input, $dialog) = $this->createInput($answer."\n");
 
-        $this->setExpectedException('InvalidArgumentException', 'Please answer yes, y, no, or n.');
+        self::expectException('InvalidArgumentException');
+        self::expectExceptionMessage('Please answer yes, y, no, or n.');
 
         $question = new StrictConfirmationQuestion('Do you like French fries?');
         $question->setMaxAttempts(1);
@@ -64,7 +64,7 @@ class StrictConfirmationQuestionTest extends TestCase
      * @param bool   $expected
      * @param bool   $default
      */
-    public function testAskConfirmation($question, $expected, $default = true)
+    public function testAskConfirmation(string $question, bool $expected, bool $default = true): void
     {
         list($input, $dialog) = $this->createInput($question."\n");
 
@@ -77,7 +77,7 @@ class StrictConfirmationQuestionTest extends TestCase
      *
      * @phpstan-return list<array{string, bool}>|list<array{string, bool, bool}>
      */
-    public function getAskConfirmationData()
+    public function getAskConfirmationData(): array
     {
         return array(
             array('', true),
@@ -89,7 +89,7 @@ class StrictConfirmationQuestionTest extends TestCase
         );
     }
 
-    public function testAskConfirmationWithCustomTrueAndFalseAnswer()
+    public function testAskConfirmationWithCustomTrueAndFalseAnswer(): void
     {
         $question = new StrictConfirmationQuestion('Do you like French fries?', false, '/^ja$/i', '/^nein$/i');
 
@@ -105,7 +105,7 @@ class StrictConfirmationQuestionTest extends TestCase
      *
      * @return resource
      */
-    protected function getInputStream($input)
+    protected function getInputStream(string $input)
     {
         $stream = fopen('php://memory', 'r+', false);
         $this->assertNotFalse($stream);
@@ -119,7 +119,7 @@ class StrictConfirmationQuestionTest extends TestCase
     /**
      * @return StreamOutput
      */
-    protected function createOutputInterface()
+    protected function createOutputInterface(): StreamOutput
     {
         return new StreamOutput(fopen('php://memory', 'r+', false));
     }
@@ -131,18 +131,12 @@ class StrictConfirmationQuestionTest extends TestCase
      *
      * @phpstan-return array{ArrayInput, QuestionHelper}
      */
-    protected function createInput($entry)
+    protected function createInput(string $entry): array
     {
-        $stream = $this->getInputStream($entry);
         $input = new ArrayInput(array('--no-interaction'));
-        $dialog = new QuestionHelper();
+        $input->setStream($this->getInputStream($entry));
 
-        if (method_exists($dialog, 'setInputStream')) {
-            $dialog->setInputStream($stream);
-        }
-        if ($input instanceof StreamableInputInterface) {
-            $input->setStream($stream);
-        }
+        $dialog = new QuestionHelper();
 
         return array($input, $dialog);
     }
