@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,7 @@ use Composer\Util\Filesystem;
 
 class FilesystemRepositoryTest extends TestCase
 {
-    public function testRepositoryRead()
+    public function testRepositoryRead(): void
     {
         $json = $this->createJsonFileMock();
 
@@ -46,9 +46,9 @@ class FilesystemRepositoryTest extends TestCase
         $this->assertSame('vendor', $packages[0]->getType());
     }
 
-    public function testCorruptedRepositoryFile()
+    public function testCorruptedRepositoryFile(): void
     {
-        $this->setExpectedException('Composer\Repository\InvalidRepositoryException');
+        self::expectException('Composer\Repository\InvalidRepositoryException');
         $json = $this->createJsonFileMock();
 
         $repository = new FilesystemRepository($json);
@@ -65,7 +65,7 @@ class FilesystemRepositoryTest extends TestCase
         $repository->getPackages();
     }
 
-    public function testUnexistentRepositoryFile()
+    public function testUnexistentRepositoryFile(): void
     {
         $json = $this->createJsonFileMock();
 
@@ -79,7 +79,7 @@ class FilesystemRepositoryTest extends TestCase
         $this->assertEquals(array(), $repository->getPackages());
     }
 
-    public function testRepositoryWrite()
+    public function testRepositoryWrite(): void
     {
         $json = $this->createJsonFileMock();
 
@@ -125,18 +125,17 @@ class FilesystemRepositoryTest extends TestCase
         $repository->write(true, $im);
     }
 
-    public function testRepositoryWritesInstalledPhp()
+    public function testRepositoryWritesInstalledPhp(): void
     {
-        $dir = $this->getUniqueTmpDirectory();
+        $dir = self::getUniqueTmpDirectory();
         chdir($dir);
 
         $json = new JsonFile($dir.'/installed.json');
 
-        $rootPackage = $this->getPackage('__root__', 'dev-master', 'Composer\Package\RootPackage');
+        $rootPackage = $this->getRootPackage('__root__', 'dev-master');
         $rootPackage->setSourceReference('sourceref-by-default');
         $rootPackage->setDistReference('distref');
         $this->configureLinks($rootPackage, array('provide' => array('foo/impl' => '2.0')));
-        /** @var RootAliasPackage $rootPackage */
         $rootPackage = $this->getAliasPackage($rootPackage, '1.10.x-dev');
 
         $repository = new FilesystemRepository($json, true, $rootPackage);
@@ -171,7 +170,7 @@ class FilesystemRepositoryTest extends TestCase
             ->getMock();
         $im->expects($this->any())
             ->method('getInstallPath')
-            ->will($this->returnCallback(function ($package) use ($dir) {
+            ->will($this->returnCallback(function ($package) use ($dir): string {
                 // check for empty paths handling
                 if ($package->getType() === 'metapackage') {
                     return '';
