@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -12,11 +12,15 @@
 
 namespace Composer\Test\Repository\Vcs;
 
+use Composer\IO\IOInterface;
+use Composer\Json\JsonFile;
 use Composer\Repository\Vcs\GitLabDriver;
 use Composer\Config;
+use Composer\Test\Mock\HttpDownloaderMock;
 use Composer\Test\TestCase;
 use Composer\Util\Filesystem;
-use Prophecy\Argument;
+use Composer\Util\ProcessExecutor;
+use PHPUnit\Framework\MockObject\MockObject;
 use Composer\Util\Http\Response;
 
 /**
@@ -33,46 +37,45 @@ class GitLabDriverTest extends TestCase
      */
     private $config;
     /**
-     * @var \Prophecy\Prophecy\ObjectProphecy
+     * @var MockObject&IOInterface
      */
     private $io;
     /**
-     * @var \Prophecy\Prophecy\ObjectProphecy
+     * @var MockObject&ProcessExecutor
      */
     private $process;
     /**
-     * @var \Prophecy\Prophecy\ObjectProphecy
+     * @var HttpDownloaderMock
      */
     private $httpDownloader;
 
-    public function setUp()
+    public function setUp(): void
     {
-        $this->home = $this->getUniqueTmpDirectory();
-        $this->config = new Config();
-        $this->config->merge(array(
-            'config' => array(
-                'home' => $this->home,
-                'gitlab-domains' => array(
-                    'mycompany.com/gitlab',
-                    'gitlab.mycompany.com',
-                    'othercompany.com/nested/gitlab',
-                    'gitlab.com',
-                ),
+        $this->home = self::getUniqueTmpDirectory();
+        $this->config = $this->getConfig([
+            'home' => $this->home,
+            'gitlab-domains' => array(
+                'mycompany.com/gitlab',
+                'gitlab.mycompany.com',
+                'othercompany.com/nested/gitlab',
+                'gitlab.com',
+                'gitlab.mycompany.local',
             ),
-        ));
+        ]);
 
-        $this->io = $this->prophesize('Composer\IO\IOInterface');
-        $this->process = $this->prophesize('Composer\Util\ProcessExecutor');
-        $this->httpDownloader = $this->prophesize('Composer\Util\HttpDownloader');
+        $this->io = $this->getMockBuilder('Composer\IO\IOInterface')->disableOriginalConstructor()->getMock();
+        $this->process = $this->getMockBuilder('Composer\Util\ProcessExecutor')->getMock();
+        $this->httpDownloader = $this->getHttpDownloaderMock();
     }
 
-    public function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         $fs = new Filesystem();
         $fs->removeDirectory($this->home);
     }
 
-    public function provideInitializeUrls()
+    public function provideInitializeUrls(): array
     {
         return array(
             array('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject'),
@@ -87,7 +90,7 @@ class GitLabDriverTest extends TestCase
      * @param string $url
      * @param string $apiUrl
      */
-    public function testInitialize($url, $apiUrl)
+    public function testInitialize(string $url, string $apiUrl): GitLabDriver
     {
         // @link http://doc.gitlab.com/ce/api/projects.html#get-single-project
         $projectData = <<<JSON
@@ -108,11 +111,12 @@ class GitLabDriverTest extends TestCase
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
@@ -129,7 +133,7 @@ JSON;
      * @param string $url
      * @param string $apiUrl
      */
-    public function testInitializePublicProject($url, $apiUrl)
+    public function testInitializePublicProject(string $url, string $apiUrl): GitLabDriver
     {
         // @link http://doc.gitlab.com/ce/api/projects.html#get-single-project
         $projectData = <<<JSON
@@ -148,11 +152,12 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
@@ -169,7 +174,7 @@ JSON;
      * @param string $url
      * @param string $apiUrl
      */
-    public function testInitializePublicProjectAsAnonymous($url, $apiUrl)
+    public function testInitializePublicProjectAsAnonymous(string $url, string $apiUrl): GitLabDriver
     {
         // @link http://doc.gitlab.com/ce/api/projects.html#get-single-project
         $projectData = <<<JSON
@@ -187,11 +192,12 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
@@ -207,7 +213,7 @@ JSON;
      *
      * @group gitlabHttpPort
      */
-    public function testInitializeWithPortNumber()
+    public function testInitializeWithPortNumber(): void
     {
         $domain = 'gitlab.mycompany.com';
         $port = '5443';
@@ -227,10 +233,12 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), sprintf($projectData, $domain, $port, $namespace))
-            ->shouldBeCalledTimes(1);
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => sprintf($projectData, $domain, $port, $namespace)]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
@@ -239,7 +247,7 @@ JSON;
         $this->assertEquals($url, $driver->getUrl());
     }
 
-    public function testGetDist()
+    public function testGetDist(): void
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
@@ -254,7 +262,7 @@ JSON;
         $this->assertEquals($expected, $driver->getDist($reference));
     }
 
-    public function testGetSource()
+    public function testGetSource(): void
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
@@ -268,7 +276,7 @@ JSON;
         $this->assertEquals($expected, $driver->getSource($reference));
     }
 
-    public function testGetSource_GivenPublicProject()
+    public function testGetSource_GivenPublicProject(): void
     {
         $driver = $this->testInitializePublicProject('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
@@ -282,7 +290,7 @@ JSON;
         $this->assertEquals($expected, $driver->getSource($reference));
     }
 
-    public function testGetTags()
+    public function testGetTags(): void
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
@@ -308,11 +316,11 @@ JSON;
 ]
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $tagData)
-            ->shouldBeCalledTimes(1)
-        ;
-
-        $driver->setHttpDownloader($this->httpDownloader->reveal());
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $tagData]],
+            true
+        );
+        $driver->setHttpDownloader($this->httpDownloader);
 
         $expected = array(
             'v1.0.0' => '092ed2c762bbae331e3f51d4a17f67310bf99a81',
@@ -323,12 +331,10 @@ JSON;
         $this->assertEquals($expected, $driver->getTags(), 'Tags are cached');
     }
 
-    public function testGetPaginatedRefs()
+    public function testGetPaginatedRefs(): void
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
-        $apiUrl = 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/branches?per_page=100';
-
         // @link http://doc.gitlab.com/ce/api/repositories.html#list-project-repository-branches
         $branchData = array(
             array(
@@ -357,22 +363,25 @@ JSON;
             );
         }
 
-        $branchData = json_encode($branchData);
+        $branchData = JsonFile::encode($branchData);
 
-        $headers = array('Link: <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20>; rel="next", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=1&per_page=20>; rel="first", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=3&per_page=20>; rel="last"');
-        $this->httpDownloader
-            ->get($apiUrl, array())
-            ->willReturn(new Response(array('url' => $apiUrl), 200, $headers, $branchData))
-            ->shouldBeCalledTimes(1);
+        $this->httpDownloader->expects(
+            [
+                [
+                    'url' => 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/branches?per_page=100',
+                    'body' => $branchData,
+                    'headers' => array('Link: <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20>; rel="next", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=1&per_page=20>; rel="first", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=3&per_page=20>; rel="last"'),
+                ],
+                [
+                    'url' => "http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20",
+                    'body' => $branchData,
+                    'headers' => array('Link: <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20>; rel="prev", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=1&per_page=20>; rel="first", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=3&per_page=20>; rel="last"'),
+                ],
+            ],
+            true
+        );
 
-        $apiUrl = "http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20";
-        $headers = array('Link: <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=2&per_page=20>; rel="prev", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=1&per_page=20>; rel="first", <http://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/tags?id=mygroup%2Fmyproject&page=3&per_page=20>; rel="last"');
-        $this->httpDownloader
-            ->get($apiUrl, array())
-            ->willReturn(new Response(array('url' => $apiUrl), 200, $headers, $branchData))
-            ->shouldBeCalledTimes(1);
-
-        $driver->setHttpDownloader($this->httpDownloader->reveal());
+        $driver->setHttpDownloader($this->httpDownloader);
 
         $expected = array(
             'mymaster' => '97eda36b5c1dd953a3792865c222d4e85e5f302e',
@@ -384,7 +393,7 @@ JSON;
         $this->assertEquals($expected, $driver->getBranches(), 'Branches are cached');
     }
 
-    public function testGetBranches()
+    public function testGetBranches(): void
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
 
@@ -410,11 +419,12 @@ JSON;
 ]
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $branchData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $branchData]],
+            true
+        );
 
-        $driver->setHttpDownloader($this->httpDownloader->reveal());
+        $driver->setHttpDownloader($this->httpDownloader);
 
         $expected = array(
             'mymaster' => '97eda36b5c1dd953a3792865c222d4e85e5f302e',
@@ -432,12 +442,12 @@ JSON;
      * @param string $url
      * @param bool   $expected
      */
-    public function testSupports($url, $expected)
+    public function testSupports(string $url, bool $expected): void
     {
-        $this->assertSame($expected, GitLabDriver::supports($this->io->reveal(), $this->config, $url));
+        $this->assertSame($expected, GitLabDriver::supports($this->io, $this->config, $url));
     }
 
-    public function dataForTestSupports()
+    public function dataForTestSupports(): array
     {
         return array(
             array('http://gitlab.com/foo/bar', true),
@@ -461,7 +471,7 @@ JSON;
         );
     }
 
-    public function testGitlabSubDirectory()
+    public function testGitlabSubDirectory(): void
     {
         $url = 'https://mycompany.com/gitlab/mygroup/my-pro.ject';
         $apiUrl = 'https://mycompany.com/gitlab/api/v4/projects/mygroup%2Fmy-pro%2Eject';
@@ -482,17 +492,18 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
     }
 
-    public function testGitlabSubGroup()
+    public function testGitlabSubGroup(): void
     {
         $url = 'https://gitlab.com/mygroup/mysubgroup/myproject';
         $apiUrl = 'https://gitlab.com/api/v4/projects/mygroup%2Fmysubgroup%2Fmyproject';
@@ -513,17 +524,18 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
     }
 
-    public function testGitlabSubDirectorySubGroup()
+    public function testGitlabSubDirectorySubGroup(): void
     {
         $url = 'https://mycompany.com/gitlab/mygroup/mysubgroup/myproject';
         $apiUrl = 'https://mycompany.com/gitlab/api/v4/projects/mygroup%2Fmysubgroup%2Fmyproject';
@@ -544,17 +556,18 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $this->config, $this->httpDownloader, $this->process);
         $driver->initialize();
 
         $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
     }
 
-    public function testForwardsOptions()
+    public function testForwardsOptions(): void
     {
         $options = array(
             'ssl' => array(
@@ -577,20 +590,22 @@ JSON;
 }
 JSON;
 
-        $this->mockResponse(Argument::cetera(), $options, $projectData)
-            ->shouldBeCalled();
+        $this->httpDownloader->expects(
+            [['url' => 'https://gitlab.mycompany.local/api/v4/projects/mygroup%2Fmyproject', 'body' => $projectData]],
+            true
+        );
 
         $driver = new GitLabDriver(
             array('url' => 'https://gitlab.mycompany.local/mygroup/myproject', 'options' => $options),
-            $this->io->reveal(),
+            $this->io,
             $this->config,
-            $this->httpDownloader->reveal(),
-            $this->process->reveal()
+            $this->httpDownloader,
+            $this->process
         );
         $driver->initialize();
     }
 
-    public function testProtocolOverrideRepositoryUrlGeneration()
+    public function testProtocolOverrideRepositoryUrlGeneration(): void
     {
         // @link http://doc.gitlab.com/ce/api/projects.html#get-single-project
         $projectData = <<<JSON
@@ -611,28 +626,15 @@ JSON;
 
         $apiUrl = 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject';
         $url = 'git@gitlab.com:mygroup/myproject';
-        $this->mockResponse($apiUrl, array(), $projectData)
-            ->shouldBeCalledTimes(1)
-        ;
+        $this->httpDownloader->expects(
+            [['url' => $apiUrl, 'body' => $projectData]],
+            true
+        );
 
         $config = clone $this->config;
         $config->merge(array('config' => array('gitlab-protocol' => 'http')));
-        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $config, $this->httpDownloader->reveal(), $this->process->reveal());
+        $driver = new GitLabDriver(array('url' => $url), $this->io, $config, $this->httpDownloader, $this->process);
         $driver->initialize();
         $this->assertEquals('https://gitlab.com/mygroup/myproject.git', $driver->getRepositoryUrl(), 'Repository URL matches config request for http not git');
     }
-
-    /**
-     * @param string      $url
-     * @param mixed[]     $options
-     * @param string|null $return
-     *
-     * @return \Prophecy\Prophecy\MethodProphecy
-     */
-    private function mockResponse($url, $options, $return)
-    {
-        return $this->httpDownloader
-            ->get($url, $options)
-            ->willReturn(new Response(array('url' => $url), 200, array(), $return));
-    }
 }
