@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -27,10 +27,10 @@ class HgDriverTest extends TestCase
     /** @var string */
     private $home;
 
-    public function setUp()
+    public function setUp(): void
     {
         $this->io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
-        $this->home = $this->getUniqueTmpDirectory();
+        $this->home = self::getUniqueTmpDirectory();
         $this->config = new Config();
         $this->config->merge(array(
             'config' => array(
@@ -39,8 +39,9 @@ class HgDriverTest extends TestCase
         ));
     }
 
-    public function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         $fs = new Filesystem;
         $fs->removeDirectory($this->home);
     }
@@ -50,14 +51,14 @@ class HgDriverTest extends TestCase
      *
      * @param string $repositoryUrl
      */
-    public function testSupports($repositoryUrl)
+    public function testSupports(string $repositoryUrl): void
     {
         $this->assertTrue(
             HgDriver::supports($this->io, $this->config, $repositoryUrl)
         );
     }
 
-    public function supportsDataProvider()
+    public function supportsDataProvider(): array
     {
         return array(
             array('ssh://bitbucket.org/user/repo'),
@@ -68,9 +69,9 @@ class HgDriverTest extends TestCase
         );
     }
 
-    public function testGetBranchesFilterInvalidBranchNames()
+    public function testGetBranchesFilterInvalidBranchNames(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
 
         $driver = new HgDriver(array('url' => 'https://example.org/acme.git'), $this->io, $this->config, $this->getMockBuilder('Composer\Util\HttpDownloader')->disableOriginalConstructor()->getMock(), $process);
 
@@ -101,11 +102,11 @@ HG_BOOKMARKS;
         ), $branches);
     }
 
-    public function testFileGetContentInvalidIdentifier()
+    public function testFileGetContentInvalidIdentifier(): void
     {
-        $this->setExpectedException('\RuntimeException');
+        self::expectException('\RuntimeException');
 
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $driver = new HgDriver(array('url' => 'https://example.org/acme.git'), $this->io, $this->config, $this->getMockBuilder('Composer\Util\HttpDownloader')->disableOriginalConstructor()->getMock(), $process);
 
         $this->assertNull($driver->getFileContent('file.txt', 'h'));
