@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -15,7 +15,6 @@ namespace Composer\Test\Util;
 use Composer\Util\Bitbucket;
 use Composer\Util\Http\Response;
 use Composer\Test\TestCase;
-use Composer\Test\Mock\ProcessExecutorMock;
 
 /**
  * @author Paul Wenke <wenke.paul@gmail.com>
@@ -48,7 +47,7 @@ class BitbucketTest extends TestCase
     /** @var int */
     private $time;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->io = $this
             ->getMockBuilder('Composer\IO\ConsoleIO')
@@ -69,7 +68,7 @@ class BitbucketTest extends TestCase
         $this->bitbucket = new Bitbucket($this->io, $this->config, null, $this->httpDownloader, $this->time);
     }
 
-    public function testRequestAccessTokenWithValidOAuthConsumer()
+    public function testRequestAccessTokenWithValidOAuthConsumer(): void
     {
         $this->io->expects($this->once())
             ->method('setAuthentication')
@@ -112,7 +111,7 @@ class BitbucketTest extends TestCase
         );
     }
 
-    public function testRequestAccessTokenWithValidOAuthConsumerAndValidStoredAccessToken()
+    public function testRequestAccessTokenWithValidOAuthConsumerAndValidStoredAccessToken(): Bitbucket
     {
         $this->config->expects($this->once())
             ->method('get')
@@ -136,7 +135,7 @@ class BitbucketTest extends TestCase
         return $this->bitbucket;
     }
 
-    public function testRequestAccessTokenWithValidOAuthConsumerAndExpiredAccessToken()
+    public function testRequestAccessTokenWithValidOAuthConsumerAndExpiredAccessToken(): void
     {
         $this->config->expects($this->once())
             ->method('get')
@@ -188,7 +187,7 @@ class BitbucketTest extends TestCase
         );
     }
 
-    public function testRequestAccessTokenWithUsernameAndPassword()
+    public function testRequestAccessTokenWithUsernameAndPassword(): void
     {
         $this->io->expects($this->once())
             ->method('setAuthentication')
@@ -198,9 +197,10 @@ class BitbucketTest extends TestCase
             ->method('writeError')
             ->withConsecutive(
                 array('<error>Invalid OAuth consumer provided.</error>'),
-                array('This can have two reasons:'),
+                array('This can have three reasons:'),
                 array('1. You are authenticating with a bitbucket username/password combination'),
-                array('2. You are using an OAuth consumer, but didn\'t configure a (dummy) callback url')
+                array('2. You are using an OAuth consumer, but didn\'t configure a (dummy) callback url'),
+                array('3. You are using an OAuth consumer, but didn\'t configure it as private consumer')
             );
 
         $this->httpDownloader->expects($this->once())
@@ -233,7 +233,7 @@ class BitbucketTest extends TestCase
         $this->assertEquals('', $this->bitbucket->requestToken($this->origin, $this->username, $this->password));
     }
 
-    public function testRequestAccessTokenWithUsernameAndPasswordWithUnauthorizedResponse()
+    public function testRequestAccessTokenWithUsernameAndPasswordWithUnauthorizedResponse(): void
     {
         $this->config->expects($this->once())
             ->method('get')
@@ -268,9 +268,9 @@ class BitbucketTest extends TestCase
         $this->assertEquals('', $this->bitbucket->requestToken($this->origin, $this->username, $this->password));
     }
 
-    public function testRequestAccessTokenWithUsernameAndPasswordWithNotFoundResponse()
+    public function testRequestAccessTokenWithUsernameAndPasswordWithNotFoundResponse(): void
     {
-        $this->setExpectedException('Composer\Downloader\TransportException');
+        self::expectException('Composer\Downloader\TransportException');
         $this->config->expects($this->once())
             ->method('get')
             ->with('bitbucket-oauth')
@@ -298,12 +298,12 @@ class BitbucketTest extends TestCase
         $this->bitbucket->requestToken($this->origin, $this->username, $this->password);
     }
 
-    public function testUsernamePasswordAuthenticationFlow()
+    public function testUsernamePasswordAuthenticationFlow(): void
     {
         $this->io
-            ->expects($this->at(0))
+            ->expects($this->atLeastOnce())
             ->method('writeError')
-            ->with($this->message)
+            ->withConsecutive([$this->message])
         ;
 
         $this->io->expects($this->exactly(2))
@@ -339,7 +339,7 @@ class BitbucketTest extends TestCase
         $this->assertTrue($this->bitbucket->authorizeOAuthInteractively($this->origin, $this->message));
     }
 
-    public function testAuthorizeOAuthInteractivelyWithEmptyUsername()
+    public function testAuthorizeOAuthInteractivelyWithEmptyUsername(): void
     {
         $authConfigSourceMock = $this->getMockBuilder('Composer\Config\ConfigSourceInterface')->getMock();
         $this->config->expects($this->atLeastOnce())
@@ -354,7 +354,7 @@ class BitbucketTest extends TestCase
         $this->assertFalse($this->bitbucket->authorizeOAuthInteractively($this->origin, $this->message));
     }
 
-    public function testAuthorizeOAuthInteractivelyWithEmptyPassword()
+    public function testAuthorizeOAuthInteractivelyWithEmptyPassword(): void
     {
         $authConfigSourceMock = $this->getMockBuilder('Composer\Config\ConfigSourceInterface')->getMock();
         $this->config->expects($this->atLeastOnce())
@@ -372,7 +372,7 @@ class BitbucketTest extends TestCase
         $this->assertFalse($this->bitbucket->authorizeOAuthInteractively($this->origin, $this->message));
     }
 
-    public function testAuthorizeOAuthInteractivelyWithRequestAccessTokenFailure()
+    public function testAuthorizeOAuthInteractivelyWithRequestAccessTokenFailure(): void
     {
         $authConfigSourceMock = $this->getMockBuilder('Composer\Config\ConfigSourceInterface')->getMock();
         $this->config->expects($this->atLeastOnce())
@@ -412,7 +412,7 @@ class BitbucketTest extends TestCase
      *
      * @return void
      */
-    private function setExpectationsForStoringAccessToken($removeBasicAuth = false)
+    private function setExpectationsForStoringAccessToken(bool $removeBasicAuth = false): void
     {
         $configSourceMock = $this->getMockBuilder('Composer\Config\ConfigSourceInterface')->getMock();
         $this->config->expects($this->once())
@@ -447,7 +447,7 @@ class BitbucketTest extends TestCase
         }
     }
 
-    public function testGetTokenWithoutAccessToken()
+    public function testGetTokenWithoutAccessToken(): void
     {
         $this->assertSame('', $this->bitbucket->getToken());
     }
@@ -457,19 +457,19 @@ class BitbucketTest extends TestCase
      *
      * @param Bitbucket $bitbucket
      */
-    public function testGetTokenWithAccessToken(Bitbucket $bitbucket)
+    public function testGetTokenWithAccessToken(Bitbucket $bitbucket): void
     {
         $this->assertSame($this->token, $bitbucket->getToken());
     }
 
-    public function testAuthorizeOAuthWithWrongOriginUrl()
+    public function testAuthorizeOAuthWithWrongOriginUrl(): void
     {
         $this->assertFalse($this->bitbucket->authorizeOAuth('non-' . $this->origin));
     }
 
-    public function testAuthorizeOAuthWithoutAvailableGitConfigToken()
+    public function testAuthorizeOAuthWithoutAvailableGitConfigToken(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
         $process->expects(array(), false, array('return' => -1));
 
         $bitbucket = new Bitbucket($this->io, $this->config, $process, $this->httpDownloader, $this->time);
@@ -477,9 +477,9 @@ class BitbucketTest extends TestCase
         $this->assertFalse($bitbucket->authorizeOAuth($this->origin));
     }
 
-    public function testAuthorizeOAuthWithAvailableGitConfigToken()
+    public function testAuthorizeOAuthWithAvailableGitConfigToken(): void
     {
-        $process = new ProcessExecutorMock;
+        $process = $this->getProcessExecutorMock();
 
         $bitbucket = new Bitbucket($this->io, $this->config, $process, $this->httpDownloader, $this->time);
 
