@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -32,11 +32,11 @@ class GitTest extends TestCase
     /** @var Filesystem&\PHPUnit\Framework\MockObject\MockObject */
     private $fs;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->io = $this->getMockBuilder('Composer\IO\IOInterface')->getMock();
         $this->config = $this->getMockBuilder('Composer\Config')->disableOriginalConstructor()->getMock();
-        $this->process = new ProcessExecutorMock;
+        $this->process = $this->getProcessExecutorMock();
         $this->fs = $this->getMockBuilder('Composer\Util\Filesystem')->disableOriginalConstructor()->getMock();
         $this->git = new Git($this->io, $this->config, $this->process, $this->fs);
     }
@@ -47,11 +47,10 @@ class GitTest extends TestCase
      * @param string $protocol
      * @param string $expectedUrl
      */
-    public function testRunCommandPublicGitHubRepositoryNotInitialClone($protocol, $expectedUrl)
+    public function testRunCommandPublicGitHubRepositoryNotInitialClone(string $protocol, string $expectedUrl): void
     {
-        $that = $this;
-        $commandCallable = function ($url) use ($that, $expectedUrl) {
-            $that->assertSame($expectedUrl, $url);
+        $commandCallable = function ($url) use ($expectedUrl): string {
+            $this->assertSame($expectedUrl, $url);
 
             return 'git command';
         };
@@ -61,11 +60,9 @@ class GitTest extends TestCase
         $this->process->expects(array('git command'), true);
 
         $this->git->runCommand($commandCallable, 'https://github.com/acme/repo', null, true);
-
-        $this->process->assertComplete($this);
     }
 
-    public function publicGithubNoCredentialsProvider()
+    public function publicGithubNoCredentialsProvider(): array
     {
         return array(
             array('ssh', 'git@github.com:acme/repo'),
@@ -73,13 +70,12 @@ class GitTest extends TestCase
         );
     }
 
-    public function testRunCommandPrivateGitHubRepositoryNotInitialCloneNotInteractiveWithoutAuthentication()
+    public function testRunCommandPrivateGitHubRepositoryNotInitialCloneNotInteractiveWithoutAuthentication(): void
     {
-        $this->setExpectedException('RuntimeException');
+        self::expectException('RuntimeException');
 
-        $that = $this;
-        $commandCallable = function ($url) use ($that) {
-            $that->assertSame('https://github.com/acme/repo', $url);
+        $commandCallable = function ($url): string {
+            $this->assertSame('https://github.com/acme/repo', $url);
 
             return 'git command';
         };
@@ -92,8 +88,6 @@ class GitTest extends TestCase
         ), true);
 
         $this->git->runCommand($commandCallable, 'https://github.com/acme/repo', null, true);
-
-        $this->process->assertComplete($this);
     }
 
     /**
@@ -105,9 +99,9 @@ class GitTest extends TestCase
      * @param string $expectedUrl
      * @param int    $expectedFailuresBeforeSuccess
      */
-    public function testRunCommandPrivateGitHubRepositoryNotInitialCloneNotInteractiveWithAuthentication($gitUrl, $protocol, $gitHubToken, $expectedUrl, $expectedFailuresBeforeSuccess)
+    public function testRunCommandPrivateGitHubRepositoryNotInitialCloneNotInteractiveWithAuthentication(string $gitUrl, string $protocol, string $gitHubToken, string $expectedUrl, int $expectedFailuresBeforeSuccess): void
     {
-        $commandCallable = function ($url) use ($expectedUrl) {
+        $commandCallable = function ($url) use ($expectedUrl): string {
             if ($url !== $expectedUrl) {
                 return 'git command failing';
             }
@@ -139,11 +133,9 @@ class GitTest extends TestCase
             ->willReturn(array('username' => 'token', 'password' => $gitHubToken));
 
         $this->git->runCommand($commandCallable, $gitUrl, null, true);
-
-        $this->process->assertComplete($this);
     }
 
-    public function privateGithubWithCredentialsProvider()
+    public function privateGithubWithCredentialsProvider(): array
     {
         return array(
             array('git@github.com:acme/repo.git', 'ssh', 'MY_GITHUB_TOKEN', 'https://token:MY_GITHUB_TOKEN@github.com/acme/repo.git', 1),
@@ -156,7 +148,7 @@ class GitTest extends TestCase
      *
      * @return void
      */
-    private function mockConfig($protocol)
+    private function mockConfig(string $protocol): void
     {
         $this->config
             ->method('get')
